import { BrowserModule } from '@angular/platform-browser';
import { NgModule } from '@angular/core';
import { AppRoutingModule } from './app-routing.module';

import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { HttpClientModule, HttpClient } from '@angular/common/http';
import { NgxEchartsModule } from 'ngx-echarts';

// 主模块注册
import { LayoutModule } from './layout/layout.module';
import { SharedModule } from './shared/shared.module';
// 主组件注册
import { AppComponent } from './app.component';
import { LayoutComponent } from './layout/layout.component';
// 公共部分-侧边栏-首部-底部
import { LeftmenuComponent } from './layout/leftmenu/leftmenu.component';
import { FooterComponent } from './layout/footer/footer.component';
import { BreadcrumbComponent } from './layout/breadcrumb/breadcrumb.component';
// 国际化相关内容
// import { HttpModule, Http } from '@angular/http';
import { TranslateLoader, TranslateModule } from '@ngx-translate/core';
import { TranslateHttpLoader } from '@ngx-translate/http-loader';
// 路由拦截,加token
import {AuthInterceptor} from './shared/service/authToken';
// 页面
import { HomeComponent } from './main/home/home.component';
import { ActualDataComponent } from './main/actual-data/actual-data.component';
import { CompareComponent } from './main/compare/compare.component';
import { AlarmInfoComponent } from './main/alarm-info/alarm-info.component';
import { WarnInfoComponent } from './main/warn-info/warn-info.component';
import { CollectorManageComponent } from './main/collector-manage/collector-manage.component';
import { PersonSetComponent } from './main/person-set/person-set.component';
import { RoleManageComponent } from './main/role-manage/role-manage.component';
import { PointManageComponent } from './main/point-manage/point-manage.component';
import { OperateSetComponent } from './main/operate-set/operate-set.component';
import { LoginLogComponent } from './main/login-log/login-log.component';
import { DragComponent } from './main/drag/drag.component';
import { GatewayManageComponent } from './main/gateway-manage/gateway-manage.component';
import { XdkHistoryComponent } from './main/xdk-history/xdk-history.component';
import { CissHistoryComponent } from './main/ciss-history/ciss-history.component';
import { CissDetailComponent } from './main/ciss-detail/ciss-detail.component';
import { XdkDetailComponent } from './main/xdk-detail/xdk-detail.component';
import { AreaManageComponent } from './main/area-manage/area-manage.component';
import { GaodeMapComponent } from './main/area-manage/gaode-map/gaode-map.component';
import { FactoryManageComponent } from './main/factory-manage/factory-manage.component';
import { UserManageComponent } from './main/user-manage/user-manage.component';
import { DetailHeaderComponent } from './main/detail-header/detail-header.component';
import { DeviceTypeComponent } from './main/device-type/device-type.component';
import { DeviceModelComponent } from './main/device-model/device-model.component';
import { FactoryPaintComponent } from './main/factory-paint/factory-paint.component';
import { PointPaintComponent } from './main/point-paint/point-paint.component';
import { XdkCompareComponent } from './main/xdk-compare/xdk-compare.component';
import { CissHCompareComponent } from './main/ciss-h-compare/ciss-h-compare.component';
import { CissZCompareComponent } from './main/ciss-z-compare/ciss-z-compare.component';
import { DepartmentManageComponent } from './main/department-manage/department-manage.component';
import { HistoryDataComponent } from './main/history-data/history-data.component';
import { PointTypeComponent } from './main/point-type/point-type.component';
import { MachineRoomComponent } from './main/machine-room/machine-room.component';
import { CuttingMachineComponent } from './main/cutting-machine/cutting-machine.component';
import { CuttingMachineDetailComponent } from './main/cutting-machine-detail/cutting-machine-detail.component';
import { MachineRoomDetailComponent } from './main/machine-room-detail/machine-room-detail.component';
import { WarnEditComponent } from './main/warn-edit/warn-edit.component';
// http
import { HTTP_INTERCEPTORS } from '@angular/common/http';

export function createTranslateHttpLoader(http: HttpClient) {
  return new TranslateHttpLoader(http, './assets/i18n/', '.json');
}

/** 配置 angular i18n **/
import { registerLocaleData } from '@angular/common';
import zh from '@angular/common/locales/zh';
registerLocaleData(zh);
/** 配置 ng-zorro-antd 国际化 **/
import { NZ_I18N, en_US, zh_CN } from 'ng-zorro-antd';

@NgModule({
  declarations: [
    AppComponent,
    LayoutComponent,
    LeftmenuComponent,
    HomeComponent,
    ActualDataComponent,
    CompareComponent,
    AlarmInfoComponent,
    WarnInfoComponent,
    CollectorManageComponent,
    PersonSetComponent,
    RoleManageComponent,
    PointManageComponent,
    OperateSetComponent,
    DragComponent,
    GatewayManageComponent,
    XdkHistoryComponent,
    CissHistoryComponent,
    CissDetailComponent,
    XdkDetailComponent,
    AreaManageComponent,
    FactoryManageComponent,
    UserManageComponent,
    LoginLogComponent,
    DetailHeaderComponent,
    DeviceTypeComponent,
    DeviceModelComponent,
    FactoryPaintComponent,
    PointPaintComponent,
    FooterComponent,
    BreadcrumbComponent,
    GaodeMapComponent,
    LeftmenuComponent,
    XdkCompareComponent,
    CissHCompareComponent,
    CissZCompareComponent,
    DepartmentManageComponent,
    HistoryDataComponent,
    PointTypeComponent,
    MachineRoomComponent,
    CuttingMachineComponent,
    CuttingMachineDetailComponent,
    MachineRoomDetailComponent,
    WarnEditComponent,
  ],
  imports: [
    BrowserModule,
    NgxEchartsModule,
    LayoutModule,
    BrowserAnimationsModule,
    HttpClientModule,
    AppRoutingModule,
    BrowserAnimationsModule,
    SharedModule,
    TranslateModule.forRoot({
      loader: {
        provide: TranslateLoader,
        useFactory: (createTranslateHttpLoader),
        deps: [HttpClient]
      }
    })
  ],
  providers: [
    {provide: NZ_I18N, useValue: zh_CN},
    {
      provide: HTTP_INTERCEPTORS,
      useClass: AuthInterceptor,
      multi: true,
    }
  ],
  bootstrap: [
    AppComponent,
  ]
})
export class AppModule {
}
