import { Component, OnInit, HostListener } from '@angular/core';
import { NzMessageService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import { ApiService } from '../../shared/service/api.service';
import { Router } from '@angular/router';
import { TranslateService } from '@ngx-translate/core';

@Component({
  selector: 'app-actual-data',
  templateUrl: './actual-data.component.html',
  animations: [fadeIn],
  styles: [`
    :host ::ng-deep .ant-tabs-nav-scroll {
      background-color: #ffffff;
      border-top: 1px solid #e6e6e6;
      padding: 0 15px;
    }
    :host ::ng-deep .ant-tabs-bar {
      margin: 0;
    }
    .tag{
      border: 1px solid #ccc;
      display: inline-block;
      padding: 0 5px;
      font-size: 13px;
      border-radius: 5px;
      height: 24px;
      line-height: 21px;
    }
  `]
})
export class ActualDataComponent implements OnInit {

  req: any = {};
  req2: any = {};
  cissData = [];
  xdkData = [];
  status = [{label: 'online', value: 1}, {label: 'offline', value: 0}];
  data = [];
  param = ['temp', 'press', 'humid'];
  param2 = ['x', 'y', 'z'];
  deviceModels = [];
  params: any = [{value: 'temp'}, {value: 'press'}, {value: 'humid'},
    {value: 'mag_x'}, {value: 'mag_y'}, {value: 'mag_z'},
    {value: 'mag_r'}, {value: 'gyros_x'}, {value: 'gyros_y'},
    {value: 'gyros_z'}, {value: 'gyros'}, {value: 'light'},
    {value: 'noise'}];
  params2: any = [{value: 'x'}, {value: 'y'}, {value: 'z'},
    {value: 'temp'}, {value: 'press'}, {value: 'humid'},
    {value: 'mag_x'}, {value: 'mag_y'}, {value: 'mag_z'},
    {value: 'mag_r'}, {value: 'gyros_x'}, {value: 'gyros_y'},
    {value: 'gyros_z'}, {value: 'gyros'}, {value: 'light'},
    {value: 'noise'}];
  devices: any = [];
  isLoading = false;
  points = [];
  constructor(private api: ApiService, private message: NzMessageService,
              private router: Router, private translate: TranslateService) { }

  ngOnInit() {
    this.init();
  }

  init() {
    this.getXdkData();
    this.getCissData();
    this.getPoints();
    this.getDeviceTypes();
    this.getDeviceModels();
  }

  getDeviceModels() {
    this.isLoading = true;
    this.api.deviceModel.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.deviceModels = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getDeviceTypes() {
    this.isLoading = true;
    this.api.deviceType.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.devices = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getPoints() {
    this.isLoading = true;
    this.api.monitoringPoint.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.points = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getCissData() {
    this.isLoading = true;
    this.api.data.getCISSData(['', (data) => {
      if (data.constructor === Array) {
        this.cissData = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  queryCiss() {
    this.isLoading = true;
    const req = {
      deviceModel: null,
      factoryNo: null,
      monitoringPointName: this.req2.monitoringPointName,
      sensorName: this.req2.sensorName,
      sensorSN: this.req2.sensorSN,
      state: this.req2.state
    };
    this.api.data.getCISSDataByTerm([req, (data) => {
      if (data.constructor === Array) {
        this.cissData = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getXdkData() {
    this.isLoading = true;
    this.api.data.getXDKData(['', (data) => {
      if (data.constructor === Array) {
        this.xdkData = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  queryXdk() {
    this.isLoading = true;
    const req = {
      deviceModel: this.req.deviceModel,
      monitoringPointName: this.req.monitoringPointName,
      sensorName: this.req.sensorName,
      sensorSN: this.req.sensorSN,
      state: this.req.state
    };
    this.api.data.getXDKDataByTerm([req, (data) => {
      if (data.constructor === Array) {
        this.xdkData = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  searchCiss() {
    this.queryCiss();
  }

  getAllCiss() {
    this.req2 = {};
    this.getCissData();
  }

  searchXdk() {
    this.queryXdk();
  }

  getAllXdk() {
    this.req = {};
    this.getXdkData();
  }

  toDetail(one, type) {
    this.router.navigate(['app/dataManage/actualData/' + type + 'Detail'], { queryParams: {deviceNo: one.deviceNo} });
  }
}
