import { Component, OnInit } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { NzMessageService, NzModalService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import { PermissionService } from '../../shared/service/permission.service';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-alarm-info',
  templateUrl: './alarm-info.component.html',
  animations: [fadeIn]
})
export class AlarmInfoComponent implements OnInit {

  req: any = {};
  data = [];
  isVisible = false;
  isLoading = false;
  factorys = [];
  page = 1;
  rows = 10;
  total;
  query: any = {};

  constructor(private api: ApiService, private message: NzMessageService,
              public per: PermissionService, private translate: TranslateService) {
  }

  ngOnInit() {
    this.init();
  }

  init() {
    this.getData();
    this.getAllFactory();
  }

  getData() {
    this.isLoading = true;
    this.api.alarmLog.getAll(this.page, this.rows, ['', (data) => {
      if (data.rows && data.rows.constructor === Array) {
        this.data = data.rows;
        this.total = data.total;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  queryData() {
    this.isLoading = true;
    const req = {
      monitoringPointName: this.query.monitoringPointName,
      monitoringPointNo: this.query.monitoringPointNo,
      factoryNo: this.query.factoryNo,
      startAlarmTime: this.query.startTime,
      stopAlarmTime: this.query.endTime
    };
    this.api.alarmLog.getForTerm(this.page, this.rows, [req, (data) => {
      if (data.rows && data.rows.constructor === Array) {
        this.data = data.rows;
        this.total = data.total;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getAllFactory() {
    this.isLoading = true;
    this.api.factory.getAllForFactoryLine(['', (data) => {
      if (data.constructor === Array) {
        this.factorys = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  onSearch() {
    this.page = 1;
    this.queryData();
  }

  onGetAll() {
    this.page = 1;
    this.req = {};
    this.getData();
  }

  searchData() {
    if (this.query.alarmName || this.query.deviceName || this.query.factoryNo || this.query.sn || this.query.startTime || this.query.endTime) {
      this.queryData();
    } else {
      this.getData();
    }
  }

  handle(one) {
    this.req = {};
    this.req.alarmLogNo = one.alarmLogNo;
    this.req.faultHandle = JSON.parse(decodeURIComponent(window.sessionStorage.getItem(encodeURIComponent('_AMap_AMap.IndoorMapFunc')))).userName;
    this.isVisible = true;
    }

  cancel() {
    this.isVisible = false;
  }

  confirm() {
    this.isLoading = true;
    this.api.alarmLog.disposeAlarm([this.req, (data) => {
      if (data.code === 1) {
        this.isVisible = false;
        this.message.success(data.message || this.translate.instant('operateSuccess'));
        this.init();
      } else {
        this.message.error(data.message || this.translate.instant('operateFail'));
      }
      this.isLoading = false;
    }]);
  }

  download() {
    this.isLoading = true;
    const req = {
      monitoringPointName: this.query.monitoringPointName,
      monitoringPointNo: this.query.monitoringPointNo,
      factoryNo: this.query.factoryNo,
      startAlarmTime: this.query.startTime,
      stopAlarmTime: this.query.endTime
    };
    this.api.alarmLog.downloadExcel([req, (data) => {
      if (data.code === 1) {
        window.location.href = data.message;
      } else {
        this.message.error(data.message);
      }
      this.isLoading = false;
    }]);
  }
}
