import { Component, OnInit, EventEmitter, Output } from '@angular/core';

declare var AMap: any;
@Component({
  selector: 'app-gaode-map',
  templateUrl: './gaode-map.component.html',
  styles: [`
    #container {
      width: 100%;
      height: 300px;
      margin-bottom: 15px;
    }
  `]
})
export class GaodeMapComponent implements OnInit {

  map;
  lastMarker;
  selectPoint = {lng: '', lat: ''};
  distinct;
  @Output() childEvent = new EventEmitter<any>();
  constructor() {}

  ngOnInit() {
    this.init();
  }

  init() {
    this.map = new AMap.Map('container');
    this.map.setZoomAndCenter(10, [119.943141, 31.772073]);
    this.map.on('click', (event) => {this.addMarker(event); });
  }

  addMarker(e) {
    if (e.lnglat && e.lnglat.lng && e.lnglat.lat) {
      this.selectPoint.lat = e.lnglat.lat;
      this.selectPoint.lng = e.lnglat.lng;
      const marker = new AMap.Marker({
        icon: 'https://webapi.amap.com/theme/v1.3/markers/n/mark_b.png',
        position: [e.lnglat.lng, e.lnglat.lat]
      });
      if (this.lastMarker) {
        this.map.remove(this.lastMarker);
      }
      this.map.add(marker);
      this.map.setZoomAndCenter(13, [e.lnglat.lng, e.lnglat.lat]);
      this.childEvent.emit(this.selectPoint);
      this.lastMarker = marker;
    }
  }

  clearMarker() {
    if (this.lastMarker) {
      this.map.remove(this.lastMarker);
      this.map.setZoomAndCenter(10, [119.943141, 31.772073]);
      this.selectPoint = {lng: '', lat: ''};
      this.childEvent.emit(this.selectPoint);
    }
  }

  moveToArea(city, area) {
    // this.map.setCity(area);
    this.distinct = new AMap.DistrictSearch({level: 'district', showbiz: false, subdistrict: 0});
    this.distinct.search(area, (a, b) => {
      if (a === 'complete' && b.districtList.length >= 1) {
        const point = [b.districtList[0].center.lng, b.districtList[0].center.lat];
        this.map.setZoomAndCenter(12, point);
      }
    });
  }
}
