import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { ApiService } from '../../shared/service/api.service';
import { NzMessageService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-ciss-detail',
  templateUrl: './ciss-detail.component.html',
  animations: [fadeIn],
  styles: [`
    /*.tableBar {*/
      /*display: flex;*/
    /*}*/

    .echartsPart {
      min-width: 300px;
      width: 100%;
      height: 500px;
    }

    .left {
      width: 400px;
      padding: 30px 15px 0 0;
      border-right: 1px solid #ccc;
    }

    .right {
      width: 100%;
      /*flex: 1;*/
    }
  `]
})
export class CissDetailComponent implements OnInit {

  alarmData: Array<object> = [{label: 111}];
  selectDeviceNo = '';
  optionArray = [];
  data: any = {sensorType: ''};
  option = {
    title: {
      text: 'Step Line',
      left: '5%',
      top: '3%'
    },
    tooltip: {
      trigger: 'axis',
      formatter: (value) => {
        return value[0].data[1];
      }
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      containLabel: true
    },
    dataZoom: [
      {
        show: true,
        start: 0,
        end: 100,
        xAxisIndex: 0
      }
    ],
    xAxis: {
      type: 'value'
    },
    yAxis: {
      type: 'value'
    },
    series: [
      {
        name: 'max',
        type: 'line',
        data: [],
        symbol: 'none',
        lineStyle: {
          normal: {
            color: 'gray',
            width: 2,
            type: 'dashed'
          }
        },
      }, {
        name: 'min',
        type: 'line',
        data: [],
        symbol: 'none',
        lineStyle: {
          normal: {
            color: 'gray',
            width: 2,
            type: 'dashed'
          }
        },
      }
    ]
  };
  isLoading = false;

  constructor(private api: ApiService, private acRouter: ActivatedRoute,
              private message: NzMessageService, private translate: TranslateService) {
  }

  ngOnInit() {
    this.acRouter.queryParams.subscribe((params) => {
      this.selectDeviceNo = params.deviceNo;
      if (params.deviceNo) {
        this.getData();
      }
    });
  }

  getData() {
    this.isLoading = true;
    const req = {
      deviceNo: this.selectDeviceNo,
      // startTime: 1548832153000,
      // endTime: 1548833953000
      startTime: new Date().getTime() - 1000 * 60 * 10,
      endTime: new Date().getTime() - 1000 * 60 * 5
    };
    this.api.data.getCISS([req, (data) => {
      if (data && data.resultSensorVo) {
        this.data = data.resultSensorVo;
        const xyz = ['X', 'Y', 'Z'];
        if (data.sensorType === 'CISS-Stepworking') {
          xyz.map((item, index) => {
            if (data[item] && data[item].lineDataVos && data[item].up.length > 0) {
              this.calc(data[item].lineDataVos, data[item].up, data[item].down, index);
            } else if (data[item] && data[item].lineDataVos && data[item].lineDataVos.length > 0) {
              this.initNormalChart(data[item].lineDataVos, index);
            }
          });
        } else {
          xyz.map((item, index) => {
            if (data[item] && data[item].lineDataVos) {
              this.initNormalChart(data[item].lineDataVos, index);
            }
          });
        }
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  init() {
    this.getData();
  }

  initCharts(obj, max, min, num) {
    const option = {...this.option};
    option.series[0].data = max;
    option.series[1].data = min;
    option.series = obj.concat(option.series);
    option.title.text = num === 0 ? 'X(mg)' : num === 1 ? 'Y(mg)' : 'Z(mg)';
    this.optionArray[num] = option;
  }

  initNormalChart(data, num) {
    const len = data.length - 1;
    const obj = [];
    data.map((item, index) => {
      obj.push([index, item]);
      if (index === len) {
        const option: any = JSON.parse(JSON.stringify(this.option));
        option.title.text = num === 0 ? 'X(mg)' : num === 1 ? 'Y(mg)' : 'Z(mg)';
        option.series = [{name: 'value', type: 'line', symbol: 'none', data: obj, lineStyle: {normal: {color: 'red'}}}];
        this.optionArray[num] = option;
      }
    });
  }

  calc(obj, max, min, num) {
    const series = [];
    const maxObj = [];
    const minObj = [];
    let last;
    max.map((item, index) => {
      maxObj.push([index, item]);
      minObj.push([index, min[index]]);
      if (obj[index] && index !== max.length - 1) {
        const red: any = {name: 'value', type: 'line', symbol: 'none', data: [], lineStyle: {normal: {color: '#FA0D09'}}};
        const normal: any = {
          name: 'value',
          type: 'line',
          symbol: 'none',
          data: [],
          lineStyle: {normal: {color: '#64BAFA'}}
        };
        if (index === 0) {
          last = obj[index] > item || obj[index] < min[index] ? red : normal;
        }
        if (obj[index] > item && obj[index + 1] < max[index + 1]) {
          // youshuangjiaocha
          const data = this.cross(obj[index], obj[index + 1], item, max[index + 1], index);
          last.data.push(data[0][0]);
          last.data.push({value: data[0][1], symbol: 'none', tooltip: {formatter: '-'}});
          series.push({...last});
          last = normal;
          last.data.push({value: data[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          if (obj[index + 1] < min[index + 1]) {
            const data2 = this.cross(obj[index], obj[index + 1], min[index], min[index + 1], index);
            last.data.push({value: data2[0][1], symbol: 'none', tooltip: {formatter: '-'}});
            series.push({...last});
            last = red;
            last.data.push({value: data2[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          }
        } else if (obj[index] < min[index] && obj[index + 1] > min[index + 1]) {
          // youshuangjiaocha
          const data = this.cross(obj[index], obj[index + 1], min[index], min[index + 1], index);
          last.data.push(data[0][0]);
          last.data.push({value: data[0][1], symbol: 'none', tooltip: {formatter: '-'}});
          series.push({...last});
          last = normal;
          last.data.push({value: data[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          if (obj[index + 1] > max[index + 1]) {
            const data2 = this.cross(obj[index], obj[index + 1], item, max[index + 1], index);
            last.data.push({value: data2[0][1], symbol: 'none', tooltip: {formatter: '-'}});
            series.push({...last});
            last = red;
            last.data.push({value: data2[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          }
        } else if (obj[index] > item && obj[index + 1] > max[index + 1]) {
          last = last || red;
          last.data.push([index, obj[index]]);
        } else if (obj[index] < min[index] && obj[index + 1] < min[index + 1]) {
          last = last || red;
          last.data.push([index, obj[index]]);
        } else if (obj[index] < item && obj[index + 1] > max[index + 1]) {
          // meiyoushuangjiaocha
          const data = this.cross(obj[index], obj[index + 1], item, max[index + 1], index);
          last.data.push(data[0][0]);
          last.data.push({value: data[0][1], symbol: 'none', tooltip: {formatter: '-'}});
          series.push({...last});
          last = red;
          last.data.push({value: data[1][0], symbol: 'none', tooltip: {formatter: '-'}});
        } else if (obj[index] > min[index] && obj[index + 1] < min[index + 1]) {
          // meiyoushuangjiaocha
          const data = this.cross(obj[index], obj[index + 1], min[index], min[index + 1], index);
          last.data.push(data[0][0]);
          last.data.push({value: data[0][1], symbol: 'none', tooltip: {formatter: '-'}});
          series.push({...last});
          last = red;
          last.data.push({value: data[1][0], symbol: 'none', tooltip: {formatter: '-'}});
        } else if (obj[index] < min[index] && obj[index + 1] > min[index + 1]) {
          // youshuangjiaocha
          const data = this.cross(obj[index], obj[index + 1], min[index], min[index + 1], index);
          last.data.push(data[0][0]);
          last.data.push({value: data[0][1], symbol: 'none', tooltip: {formatter: '-'}});
          series.push({...last});
          last = normal;
          last.data.push({value: data[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          if (obj[index + 1] > max[index + 1]) {
            const data2 = this.cross(obj[index], obj[index + 1], item, max[index + 1], index);
            last.data.push({value: data2[0][1], symbol: 'none', tooltip: {formatter: '-'}});
            series.push({...last});
            last = red;
            last.data.push({value: data2[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          }
        } else {
          last = last || normal;
          last.data.push([index, obj[index]]);
        }
      } else if (index === max.length - 1) {
        series.push({...last});
        this.initCharts(series, maxObj, minObj, num);
      }
    });
  }

  cross(po11, po12, po21, po22, num) {
    const n1 = po12 - po11;
    const n2 = po22 - po21;
    const c1 = po12 - n1 * (num + 1);
    const c2 = po22 - n2 * (num + 1);
    const x = ( c2 - c1 ) / ( n1 - n2 );
    const y = n1 * x + c1;
    return [[[num, po11], [x, y]], [[x, y], [num + 1, po12]]];
  }
}
