import { Component, OnInit } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { NzMessageService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import { isUndefined } from 'util';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-ciss-h-compare',
  templateUrl: './ciss-h-compare.component.html',
  animations: [fadeIn],
  styles: [`
    .addIcon {
      width: 30px;
      display: inline-block;
      height: 0;
      margin: 0px 20px;
      position: relative;
    }
    .addIcon .iconfont.icon-tianjia {
      font-size: 30px;
      color: #52c41a;
      top: -17px;
      position: absolute;
    }
    .addIcon .iconfont.icon-delete {
      font-size: 30px;
      color: #ff2c32;
      top: -17px;
      position: absolute;
    }
    nz-input-group {
      margin-top: -5px;
    }
  `]
})
export class CissHCompareComponent implements OnInit {

  req: any = {};
  deviceNos = [];
  isLoading = false;
  selectDevices = [];
  deviceTypes = [{label: 'CISS-Stepworking', value: 'CISS-Stepworking'}, {label: 'CISS-Keepworking', value: 'CISS-Keepworking'}];
  params: any = [{value: 'x'}, {value: 'y'}, {value: 'z'},
    {value: 'temp'}, {value: 'press'}, {value: 'humid'},
    {value: 'mag_x'}, {value: 'mag_y'}, {value: 'mag_z'},
    {value: 'mag_r'}, {value: 'gyros_x'}, {value: 'gyros_y'},
    {value: 'gyros_z'}, {value: 'gyros'}, {value: 'light'},
    {value: 'noise'}];
  option = {
    title: {
      text: ''
    },
    tooltip: {
      trigger: 'axis'
    },
    legend: {
      data: []
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      containLabel: true
    },
    dataZoom: [
      {
        show: true,
        start: 0,
        end: 100,
        xAxisIndex: 0
      }
    ],
    xAxis: {
      type: 'value',
      data: []
    },
    yAxis: {
      type: 'value',
      scale: true
    },
    series: []
  };
  optionArray = [];
  selectDeviceType = '';
  canBeSelected = [];
  constructor(private api: ApiService, private message: NzMessageService, private translate: TranslateService) { }

  ngOnInit() {
    this.init();
  }

  init() {
    this.getDeviceNos();
  }

  getDeviceNos() {
    this.isLoading = true;
    const req = {type: 'ciss'};
    this.api.sensor.getUnFreeByType([req, (data) => {
      if (data.constructor === Array) {
        this.deviceNos = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  add() {
    if (this.selectDeviceType) {
      if (this.selectDevices.length === 0) {
        this.canBeSelected = this.deviceNos.filter((item) => item.sensorType === this.selectDeviceType);
      }
      if (this.selectDevices.length + 1 > this.canBeSelected.length) {
        this.message.error(this.translate.instant('moreThanCanBeSelectedSensors'));
      } else {
        this.selectDevices.push({max: '', min: ''});
      }
    } else {
      this.message.error(this.translate.instant('pleaseChooseSensorType'));
    }
  }

  deleteDevice(i) {
    this.selectDevices.splice(i, 1);
  }

  onDateChange() {
    if (this.selectDeviceType === 'CISS-Stepworking' && this.req.startTime && this.req.endTime) {
      const st = new Date(this.req.startTime).getTime();
      const et = new Date(this.req.endTime).getTime();
      if (st > et || et - st > 5 * 60 * 1000) {
        // this.message.error(this.translate.instant('startEndTimeShouldInFiveMinutes'));
      } else {
        this.selectDevices.map((one) => {
          if (one.deviceNo) {
            this.searchNum(one);
          }
        });
      }
    }
  }

  // huoqu num
  searchNum(one) {
    this.isLoading = true;
    const req = {
      deviceNo: one.deviceNo,
      endTime: new Date(this.req.endTime).getTime(),
      startTime: new Date(this.req.startTime).getTime()
    };
    this.api.data.getCISSNum([req, (data) => {
      if (data && data.minNum && data.maxNum && new RegExp( '^[0-9]*$').test(data.minNum) && new RegExp( '^[0-9]*$').test(data.maxNum)) {
        one.max = data.maxNum;
        one.min = data.minNum;
      } else {
        const msg = this.translate.instant('checkIfSerialNumberExists');
        this.message.error(data.message || msg);
      }
      this.isLoading = false;
    }]);
  }

  // dangechuanganqigaibian
  onDeviceChange(one) {
    if (JSON.stringify(this.selectDevices).split('"deviceNo":"' + one.deviceNo + '"').length > 2) {
      this.message.error(this.translate.instant('sensorBeSelected'));
      one.deviceNo = '';
      return;
    }
    if (this.selectDeviceType === 'CISS-Stepworking' && this.req.startTime && this.req.endTime) {
      const st = new Date(this.req.startTime).getTime();
      const et = new Date(this.req.endTime).getTime();
      if (st > et || et - st > 5 * 60 * 1000) {
        this.message.error(this.translate.instant('startEndTimeShouldInFiveMinutes'));
      } else {
        this.searchNum(one);
      }
    }
  }

  checkAll() {
    if (!this.selectDeviceType) {
      this.message.error(this.translate.instant('pleaseChooseSensorType'));
      return false;
    }
    if (!this.req.startTime || !this.req.endTime) {
      this.message.error(this.translate.instant('pleaseChooseStartEndTime'));
      return false;
    }
    const st = new Date(this.req.startTime).getTime();
    const et = new Date(this.req.endTime).getTime();
    if (st > et) {
      this.message.error(this.translate.instant('startShouldLessThanEndTime'));
      return false;
    }
    if (et - st > 5 * 60 * 1000) {
      this.message.error(this.translate.instant('startEndTimeShouldInFiveMinutes'));
      return false;
    }
    if (!this.req.parameter || this.req.parameter.length <= 0) {
      this.message.error(this.translate.instant('pleaseChooseCompareParams'));
      return false;
    }
    if (this.selectDeviceType === 'CISS-Stepworking') {
      const checkObj = this.selectDevices.filter((item) => item.deviceNo &&
        item.num !== null && !isUndefined(item.num) && item.min && item.max &&
        Number(item.num) >= Number(item.min) && Number(item.num) <= Number(item.max));
      if (this.selectDevices.length <= 0) {
        this.message.error(this.translate.instant('pleaseAddSensorToCompare'));
        return false;
      } else if (checkObj.length !== this.selectDevices.length) {
        this.message.error(this.translate.instant('checkIfAllSensorAndSerialNumFilled'));
        return false;
      } else {
        return true;
      }
    } else {
      const checkObj = this.selectDevices.filter((item) => item.deviceNo);
      if (checkObj.length !== this.selectDevices.length) {
        this.message.error(this.translate.instant('checkIfAllSensorFilled'));
        return false;
      } else {
        return true;
      }
    }
  }

  onSearch() {
    this.isLoading = true;
    // jiemianjiancha
    if (this.checkAll()) {
      if (this.selectDeviceType === 'CISS-Stepworking') {
        this.searchStepData();
      } else {
        this.searchKeepData();
      }
    } else {
      this.isLoading = false;
    }
  }

  searchStepData() {
    const stepWorkingCisses = [];
    this.selectDevices.map((item, index) => {
      stepWorkingCisses.push({deviceNo: item.deviceNo, num: Number(item.num)});
      if (index === this.selectDevices.length - 1) {
        const req = {
          endTime: new Date(this.req.endTime).getTime(),
          startTime: new Date(this.req.startTime).getTime(),
          parameter: '',
          stepWorkingCisses: stepWorkingCisses
        };
        this.optionArray = [];
        this.req.parameter.map((one, pIndex) => {
          req.parameter = one;
          this.getStepCissData(one, pIndex, req);
        });
      }
    });
  }

  searchKeepData() {
    const deviceNo = [];
    this.selectDevices.map((item, index) => {
      deviceNo.push(item.deviceNo);
      if (index === this.selectDevices.length - 1) {
        const req = {
          endTime: new Date(this.req.endTime).getTime(),
          startTime: new Date(this.req.startTime).getTime(),
          parameter: '',
          deviceNo: deviceNo
        };
        this.optionArray = [];
        this.req.parameter.map((one, pIndex) => {
          req.parameter = one;
          this.getKeepCissData(one, pIndex, req);
        });
      }
    });
  }

  getKeepCissData(item, pIndex, req) {
    this.api.dataComparison.getDataComparisonForKeepCiss([req, (data) => {
      if (data.constructor === Array) {
        const option = {...this.option};
        option.title.text = this.translate.instant(item) + this.translate.instant('data');
        if (data.length === 0) { this.isLoading = false; }
        data.map((one, index) => {
          const obj = [];
          if (one.keepDataVo && one.keepDataVo.lineDataVos && one.keepDataVo.lineDataVos.length > 0) {
            one.keepDataVo.lineDataVos.map((two, ind) => {
              obj.push([ind, two]);
              if (ind === one.keepDataVo.lineDataVos.length - 1) {
                option.series[index] = {
                  name: this.translate.instant('sensor') + one.sensorName + '-' + this.translate.instant(item) + this.translate.instant('data'),
                  symbol: 'none',
                  type: 'line',
                  data: obj
                };
              }
            });
          } else {
            option.series[index] = {
              name: this.translate.instant('sensor') + one.sensorName + this.translate.instant(item) + this.translate.instant('data'),
              symbol: 'none',
              type: 'line',
              data: [0, '-']
            };
          }
          option.legend.data.push(this.translate.instant('sensor') + one.sensorName + this.translate.instant(item) + this.translate.instant('data'));
          if (pIndex === this.req.parameter.length - 1 && index === data.length - 1) {
            this.optionArray[pIndex] = option;
            this.isLoading = false;
          }
        });
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
        this.isLoading = false;
      }
    }]);
  }

  getStepCissData(item, pIndex, req) {
    this.api.dataComparison.getComparisonForKeepCiss([req, (data) => {
      if (data.constructor === Array) {
        const option = {...this.option};
        option.title.text = this.translate.instant(item) + this.translate.instant('data');
        if (data.length === 0) { this.isLoading = false; }
        data.map((one, index) => {
          const obj = [];
          if (one.keepDataVo && one.keepDataVo.lineDataVos && one.keepDataVo.lineDataVos.length > 0) {
            one.keepDataVo.lineDataVos.map((two, ind) => {
              obj.push([ind, two]);
              if (ind === one.keepDataVo.lineDataVos.length - 1) {
                option.series[index] = {
                  name: this.translate.instant('sensor') + one.sensorName + '-' + this.translate.instant(item) + this.translate.instant('data'),
                  symbol: 'none',
                  type: 'line',
                  data: obj
                };
              }
            });
          } else {
            option.series[index] = {
              name: this.translate.instant('sensor') + one.sensorName + this.translate.instant(item) + this.translate.instant('data'),
              symbol: 'none',
              type: 'line',
              data: [0, '-']
            };
          }
          option.legend.data.push(this.translate.instant('sensor') + one.sensorName + this.translate.instant(item) + this.translate.instant('data'));
          this.optionArray[pIndex] = option;
          if (pIndex === this.req.parameter.length - 1 && index === data.length - 1) {
            this.isLoading = false;
          }
        });
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
        this.isLoading = false;
      }
    }]);
  }

  onNumChange(one) {
    const num = parseInt(one.num, 10);
    const min = parseInt(one.min, 10);
    const max = parseInt(one.max, 10);
    if (isNaN(num) || num < 0) {
      one.num = '';
    } else if (num > max) {
      one.num = max;
    } else if (num < min) {
      one.num = min;
    } else {
      one.num = num;
    }
  }

  numAdd(one) {
    const num = parseInt(one.num, 10);
    const min = parseInt(one.min, 10);
    const max = parseInt(one.max, 10);
    if (isNaN(num) || num + 1 < 0) {
      one.num = 1;
    } else if (num + 1 > max) {
      one.num = max;
    } else if (num + 1 < min) {
      one.num = min;
    } else {
      one.num = num + 1;
    }
  }

  numDel(one) {
    const num = parseInt(one.num, 10);
    const min = parseInt(one.min, 10);
    const max = parseInt(one.max, 10);
    if (isNaN(num) || num - 1 < 0) {
      one.num = 0;
    } else if (num - 1 > max) {
      one.num = max;
    } else if (num - 1 < min) {
      one.min = min;
    } else {
      one.num = num - 1;
    }
  }
}
