import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { NzMessageService } from 'ng-zorro-antd';
import { ApiService } from '../../shared/service/api.service';
import { fadeIn } from '../../animation/fade-in';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-ciss-history',
  templateUrl: './ciss-history.component.html',
  animations: [fadeIn],
  styles: [`
    /*.searchBar {*/
      /*display: flex;*/
    /*}*/
    /*.left {*/
      /*width: 270px;*/
      /*line-height: 40px;*/
    /*}*/
    /*.middle {*/
      /*flex: 1;*/
    /*}*/
    /*.right {*/
      /*width: 150px;*/
      /*text-align: center;*/
    /*}*/
  `]
})
export class CissHistoryComponent implements OnInit {

  params: any = [{value: 'x'}, {value: 'y'}, {value: 'z'},
    {value: 'temp'}, {value: 'press'}, {value: 'humid'},
    {value: 'mag_x'}, {value: 'mag_y'}, {value: 'mag_z'},
    {value: 'mag_r'}, {value: 'gyros_x'}, {value: 'gyros_y'},
    {value: 'gyros_z'}, {value: 'gyros'}, {value: 'light'},
    {value: 'noise'}];
  isLoading = false;
  optionArray = [];
  req: any = {};
  num = [' ', ' '];
  selectDevice: any = {};
  orOption = {
    title: {
      text: ''
    },
    tooltip: {
      trigger: 'axis'
    },
    legend: {
      data: ['']
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      containLabel: true
    },
    dataZoom: [
      {
        show: true,
        start: 0,
        end: 100
      }
    ],
    xAxis: {
      type: 'value',
      boundaryGap: false,
      data: []
    },
    yAxis: {
      type: 'value',
      scale: true
    },
    series: [
      {
        name: '',
        type: 'line',
        symbol: 'none',
        data: []
      }
    ]
  };
  udOption = {
    title: {
      text: 'Step Line',
      left: '5%',
      top: '3%'
    },
    tooltip: {
      trigger: 'axis',
      formatter: (value) => {
        return value[0].data[1];
      }
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      containLabel: true
    },
    dataZoom: [
      {
        show: true,
        start: 0,
        end: 100,
        xAxisIndex: 0
      }
    ],
    xAxis: {
      type: 'value'
    },
    yAxis: {
      type: 'value',
      scale: true
    },
    series: [
      {
        name: 'max',
        type: 'line',
        data: [],
        symbol: 'none',
        lineStyle: {
          normal: {
            color: 'gray',
            width: 2,
            type: 'dashed'
          }
        },
      }, {
        name: 'min',
        type: 'line',
        data: [],
        symbol: 'none',
        lineStyle: {
          normal: {
            color: 'gray',
            width: 2,
            type: 'dashed'
          }
        },
      }
    ]
  };
  devices = [];

  constructor(private api: ApiService, private acRouter: ActivatedRoute, private message: NzMessageService, private translate: TranslateService) {
  }

  ngOnInit() {
    this.getDevices();
    this.acRouter.queryParams.subscribe((params) => {
      this.selectDevice = params;
      if (this.selectDevice.deviceNo) {
        this.req.deviceNo = this.selectDevice.deviceNo;
      }
      if (this.selectDevice.sensorType) {
        this.req.sensorType = this.selectDevice.sensorType;
      }
    });
  }

  getDevices() {
    this.isLoading = true;
    const req = {type: 'CISS'};
    this.api.sensor.getUnFreeByType([req, (data) => {
      if (data.constructor === Array) {
        this.devices = data;
        if (this.req.deviceNo) {
          this.req.device = data.filter((item) => item.sensorDeviceNo === this.req.deviceNo)[0];
        }
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  onSearch() {
    this.isLoading = true;
    if (this.req.sensorType === 'CISS-Stepworking' && !this.req.num) {
      this.isLoading = false;
      this.message.error(this.translate.instant('pleaseFillSerialNum'));
    } else if (!this.req.startTime || !this.req.endTime || !this.req.params || this.req.params.length <= 0) {
      this.isLoading = false;
      this.message.error(!this.req.startTime ? this.translate.instant('pleaseChooseStartTime') : !this.req.endTime ? this.translate.instant('pleaseChooseEndTime') : this.translate.instant('pleaseChooseParams'));
    } else if ((new Date(this.req.endTime).getTime() + 28800000) / 86400000 < Math.floor((new Date(this.req.startTime).getTime() + 28800000) / 86400000) || (new Date(this.req.endTime).getTime() + 28800000) / 86400000 > Math.floor((new Date(this.req.startTime).getTime() + 28800000) / 86400000) + 1) {
      this.isLoading = false;
      this.message.error(this.translate.instant('startEndTimeInOneDay'));
    } else if (new Date(this.req.startTime).getTime() < new Date(this.req.endTime).getTime() - 3600 * 1000) {
      this.isLoading = false;
      this.message.error(this.translate.instant('timeShouldInOneHour'));
    } else if (new Date(this.req.startTime).getTime() > new Date(this.req.endTime).getTime()) {
      this.isLoading = false;
      this.message.error(this.translate.instant('startShouldLessThanEndTime'));
    } else {
      this.getData();
    }
  }

  init() {
  }

  getData() {
    const req: any = {
      deviceNo: this.req.deviceNo,
      startTime: new Date(this.req.startTime).getTime(),
      endTime: new Date(this.req.endTime).getTime(),
      num: this.req.sensorType === 'CISS-Stepworking' ? this.req.num : null
    };
    const params = this.req.params;
    this.optionArray = [];
    params.map((item, index) => {
      req.parameter = item;
      this.api.data.getCISSHistoryData([req, (data) => {
        if (index === params.length - 1) {
          this.isLoading = false;
        }
        if (data && data.lineDataVos && data.up && data.up.length > 0) {
          this.calc(data.lineDataVos, data.up, data.down, index, item);
        } else if (data && data.lineDataVos) {
          this.initNormalChart(data.lineDataVos, index, item);
        } else {
          this.message.error(data.message || this.translate.instant('checkIfHasData'));
          this.isLoading = false;
        }
      }]);
    });

  }

  initCharts(obj, max, min, num, name) {
    const option = {...this.udOption};
    option.series[0].data = max;
    option.series[1].data = min;
    option.series = obj.concat(option.series);
    option.title.text = this.translate.instant(name);
    this.optionArray[num] = option;
  }

  initNormalChart(data, num, name) {
    const len = data.length - 1;
    const obj = [];
    data.map((item, index) => {
      obj.push([index, item]);
      if (index === len) {
        const option: any = {...this.orOption};
        option.title.text = this.translate.instant(name);
        option.series = [{name: 'value', type: 'line', symbol: 'none', data: obj, lineStyle: {normal: {color: 'red'}}}];
        this.optionArray[num] = option;
      }
    });
  }

  calc(obj, max, min, num, name) {
    const series = [];
    const maxObj = [];
    const minObj = [];
    let last;
    max.map((item, index) => {
      maxObj.push([index, item]);
      minObj.push([index, min[index]]);
      if (obj[index] && index !== max.length - 1) {
        const red: any = {
          name: 'value',
          type: 'line',
          symbol: 'none',
          data: [],
          lineStyle: {normal: {color: '#FA0D09'}}
        };
        const normal: any = {
          name: 'value',
          type: 'line',
          symbol: 'none',
          data: [],
          lineStyle: {normal: {color: '#64BAFA'}}
        };
        if (index === 0) {
          last = obj[index] > item || obj[index] < min[index] ? red : normal;
        }
        if (obj[index] > item && obj[index + 1] < max[index + 1]) {
          // youshuangjiaocha
          const data = this.cross(obj[index], obj[index + 1], item, max[index + 1], index);
          last.data.push(data[0][0]);
          last.data.push({value: data[0][1], symbol: 'none', tooltip: {formatter: '-'}});
          series.push({...last});
          last = normal;
          last.data.push({value: data[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          if (obj[index + 1] < min[index + 1]) {
            const data2 = this.cross(obj[index], obj[index + 1], min[index], min[index + 1], index);
            last.data.push({value: data2[0][1], symbol: 'none', tooltip: {formatter: '-'}});
            series.push({...last});
            last = red;
            last.data.push({value: data2[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          }
        } else if (obj[index] < min[index] && obj[index + 1] > min[index + 1]) {
          // youshuangjiaocha
          const data = this.cross(obj[index], obj[index + 1], min[index], min[index + 1], index);
          last.data.push(data[0][0]);
          last.data.push({value: data[0][1], symbol: 'none', tooltip: {formatter: '-'}});
          series.push({...last});
          last = normal;
          last.data.push({value: data[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          if (obj[index + 1] > max[index + 1]) {
            const data2 = this.cross(obj[index], obj[index + 1], item, max[index + 1], index);
            last.data.push({value: data2[0][1], symbol: 'none', tooltip: {formatter: '-'}});
            series.push({...last});
            last = red;
            last.data.push({value: data2[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          }
        } else if (obj[index] > item && obj[index + 1] > max[index + 1]) {
          last = last || red;
          last.data.push([index, obj[index]]);
        } else if (obj[index] < min[index] && obj[index + 1] < min[index + 1]) {
          last = last || red;
          last.data.push([index, obj[index]]);
        } else if (obj[index] < item && obj[index + 1] > max[index + 1]) {
          // meiyoushuangjiaocha
          const data = this.cross(obj[index], obj[index + 1], item, max[index + 1], index);
          last.data.push(data[0][0]);
          last.data.push({value: data[0][1], symbol: 'none', tooltip: {formatter: '-'}});
          series.push({...last});
          last = red;
          last.data.push({value: data[1][0], symbol: 'none', tooltip: {formatter: '-'}});
        } else if (obj[index] > min[index] && obj[index + 1] < min[index + 1]) {
          // meiyoushuangjiaocha
          const data = this.cross(obj[index], obj[index + 1], min[index], min[index + 1], index);
          last.data.push(data[0][0]);
          last.data.push({value: data[0][1], symbol: 'none', tooltip: {formatter: '-'}});
          series.push({...last});
          last = red;
          last.data.push({value: data[1][0], symbol: 'none', tooltip: {formatter: '-'}});
        } else if (obj[index] < min[index] && obj[index + 1] > min[index + 1]) {
          // youshuangjiaocha
          const data = this.cross(obj[index], obj[index + 1], min[index], min[index + 1], index);
          last.data.push(data[0][0]);
          last.data.push({value: data[0][1], symbol: 'none', tooltip: {formatter: '-'}});
          series.push({...last});
          last = normal;
          last.data.push({value: data[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          if (obj[index + 1] > max[index + 1]) {
            const data2 = this.cross(obj[index], obj[index + 1], item, max[index + 1], index);
            last.data.push({value: data2[0][1], symbol: 'none', tooltip: {formatter: '-'}});
            series.push({...last});
            last = red;
            last.data.push({value: data2[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          }
        } else {
          last = last || normal;
          last.data.push([index, obj[index]]);
        }
      } else if (index === max.length - 1) {
        series.push({...last});
        this.initCharts(series, maxObj, minObj, num, name);
      }
    });
  }

  cross(po11, po12, po21, po22, num) {
    const n1 = po12 - po11;
    const n2 = po22 - po21;
    const c1 = po12 - n1 * (num + 1);
    const c2 = po22 - n2 * (num + 1);
    const x = ( c2 - c1 ) / ( n1 - n2 );
    const y = n1 * x + c1;
    return [[[num, po11], [x, y]], [[x, y], [num + 1, po12]]];
  }

  onDateChange(bool) {
    if (this.req.startTime && this.req.endTime) {
      if (new Date(this.req.endTime).getTime() - new Date(this.req.startTime).getTime() > 60 * 60 * 1000) {
        // this.req.endTime = new Date(new Date(this.req.startTime).getTime() + 60 * 60 * 1000);
        if (bool) { this.message.error(this.translate.instant('searchTimeInOneHour')); }
      } else {
        if (this.req.sensorType === 'CISS-Stepworking') {
          this.isLoading = true;
          const req = {
            deviceNo: this.req.deviceNo,
            endTime: new Date(this.req.endTime).getTime(),
            startTime: new Date(this.req.startTime).getTime(),
          };
          this.api.data.getCISSNum([req, (data) => {
            if (data && data.minNum && data.maxNum && new RegExp('^[0-9]*$').test(data.minNum) && new RegExp('^[0-9]*$').test(data.maxNum)) {
              this.num = [data.minNum + ' <=', '<= ' + data.maxNum];
            } else {
              if (bool) { const msg = this.translate.instant('checkIfSerialNumberExists');
              this.message.error(data.message || msg); }
            }
            this.isLoading = false;
          }]);
        }
      }
    }
  }

  onDeviceChange(e) {
    this.req.deviceNo = e.sensorDeviceNo;
    this.req.sensorType = e.sensorType;
    this.onDateChange(false);
  }

  onNumChange() {
    const num = parseInt(this.req.num, 10);
    const min = parseInt(this.num[0], 10);
    const max = parseInt(this.num[1], 10);
    if (isNaN(num) || num < 0) {
      this.req.num = '';
    } else if (num > max) {
      this.req.num = max;
    } else if (num < min) {
      this.req.min = min;
    } else {
      this.req.num = num;
    }
  }

  numAdd() {
    const num = parseInt(this.req.num, 10);
    const min = parseInt(this.num[0], 10);
    const max = parseInt(this.num[1], 10);
    if (isNaN(num) || num + 1 < 0) {
      this.req.num = 1;
    } else if (num + 1 > max) {
      this.req.num = max;
    } else if (num + 1 < min) {
      this.req.min = min;
    } else {
      this.req.num = num + 1;
    }
  }

  numDel() {
    const num = parseInt(this.req.num, 10);
    const min = parseInt(this.num[0], 10);
    const max = parseInt(this.num[1], 10);
    if (isNaN(num) || num - 1 < 0) {
      this.req.num = 0;
    } else if (num - 1 > max) {
      this.req.num = max;
    } else if (num - 1 < min) {
      this.req.min = min;
    } else {
      this.req.num = num - 1;
    }
  }

  download() {
    this.isLoading = true;
    if (!this.req.startTime || !this.req.endTime) {
      this.isLoading = false;
      this.message.error(!this.req.startTime ? this.translate.instant('pleaseChooseStartTime') : this.translate.instant('pleaseChooseEndTime'));
    } else if ((new Date(this.req.endTime).getTime() + 28800000) / 86400000 < Math.floor((new Date(this.req.startTime).getTime() + 28800000) / 86400000) || (new Date(this.req.endTime).getTime() + 28800000) / 86400000 > Math.floor((new Date(this.req.startTime).getTime() + 28800000) / 86400000) + 1) {
      this.isLoading = false;
      this.message.error(this.translate.instant('startEndTimeInOneDay'));
    } else if (new Date(this.req.startTime).getTime() > new Date(this.req.endTime).getTime()) {
      this.isLoading = false;
      this.message.error(this.translate.instant('startShouldLessThanEndTime'));
    } else if (new Date(this.req.startTime).getTime() < new Date(this.req.endTime).getTime() - 3600 * 1000) {
      this.isLoading = false;
      this.message.error(this.translate.instant('timeShouldInOneHour'));
    } else if (!this.req.deviceNo) {
      this.isLoading = false;
      this.message.error(this.translate.instant('pleaseChooseDevices'));
    } else {
      this.message.success(this.translate.instant('linkingToSource'));
      this.isLoading = true;
      const req = {
        deviceNo: this.req.deviceNo,
        endTime: new Date(this.req.endTime).getTime(),
        startTime: new Date(this.req.startTime).getTime(),
      };
      this.api.download.downloadCissData([req, (data) => {
        if (data.code === 1) {
          window.location.href = this.api.imgUrl + '/assets/file/' + data.message;
          this.message.success(this.translate.instant('startDownload'));
        } else {
          this.message.error(data.message);
        }
        this.isLoading = false;
      }]);
    }
  }
}
