import { Component, OnInit } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { NzMessageService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-ciss-z-compare',
  templateUrl: './ciss-z-compare.component.html',
  animations: [fadeIn],
  styles: []
})
export class CissZCompareComponent implements OnInit {

  req: any = {startTime: '', endTime: ''};
  deviceNos = [];
  isLoading = false;
  showNum = false;
  optionQuery = {
    temp: [], press: [], humid: [], mag_x: [], mag_y: [],
    mag_z: [], mag_r: [], acc_x: [], acc_y: [], acc_z: [], noise: [],
    gyros_x: [], gyros_y: [], gyros_z: [], light: [], x: [], y: [], z: []
  };
  num: Array<string> = [' ', ' '];
  selectDevice: any = {};
  params: any = [{value: 'x'}, {value: 'y'}, {value: 'z'},
    {value: 'temp'}, {value: 'press'}, {value: 'humid'},
    {value: 'mag_x'}, {value: 'mag_y'}, {value: 'mag_z'},
    {value: 'mag_r'}, {value: 'gyros_x'}, {value: 'gyros_y'},
    {value: 'gyros_z'}, {value: 'gyros'}, {value: 'light'},
    {value: 'noise'}];
  orOption = {
    title: {
      text: ''
    },
    tooltip: {
      trigger: 'axis'
    },
    legend: {
      data: ['']
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      containLabel: true
    },
    dataZoom: [
      {
        show: true,
        start: 0,
        end: 100
      }
    ],
    xAxis: {
      type: 'value',
      boundaryGap: false,
      data: []
    },
    yAxis: {
      type: 'value',
      scale: true
    },
    series: [
      {
        name: '',
        type: 'line',
        symbol: 'none',
        data: []
      }
    ]
  };
  udOption = {
    title: {
      text: 'Step Line',
      left: '5%',
      top: '3%'
    },
    tooltip: {
      trigger: 'axis',
      formatter: (value) => {
        return value[0].data[1];
      }
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      containLabel: true
    },
    dataZoom: [
      {
        show: true,
        start: 0,
        end: 100,
        xAxisIndex: 0
      }
    ],
    xAxis: {
      type: 'value'
    },
    yAxis: {
      type: 'value',
      scale: true
    },
    series: [
      {
        name: 'max',
        type: 'line',
        data: [],
        symbol: 'none',
        lineStyle: {
          normal: {
            color: 'gray',
            width: 2,
            type: 'dashed'
          }
        },
      }, {
        name: 'min',
        type: 'line',
        data: [],
        symbol: 'none',
        lineStyle: {
          normal: {
            color: 'gray',
            width: 2,
            type: 'dashed'
          }
        },
      }
    ]
  };
  lastQuery = '';
  constructor(private api: ApiService, private message: NzMessageService, private translate: TranslateService) { }

  ngOnInit() {
    this.init();
  }

  init() {
    this.getDeviceNos();
  }

  getDeviceNos() {
    this.isLoading = true;
    const req = {type: 'ciss'};
    this.api.sensor.getUnFreeByType([req, (data) => {
      if (data.constructor === Array) {
        this.deviceNos = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  onSearch() {
    this.isLoading = true;
    if (!this.req.startTime || !this.req.endTime || !this.req.deviceNo || !this.req.parameter || this.req.parameter.length <= 0) {
      const msg = !this.req.startTime ? this.translate.instant('pleaseChooseStartTime') : !this.req.endTime ? this.translate.instant('pleaseChooseEndTime') : !this.req.deviceNo ? this.translate.instant('pleaseChooseSensor') : this.translate.instant('pleaseChooseCompareParams');
      this.isLoading = false;
      this.message.error(msg);
    } else if (this.showNum && !this.req.num) {
      const msg = this.translate.instant('pleaseFillSerialNum');
      this.isLoading = false;
      this.message.error(msg);
    } else {
      this.getData();
    }
  }

  getData() {
    const query = this.req.deviceNo + JSON.stringify(this.req.parameter);
    if (query !== this.lastQuery) {
      this.optionQuery = {
        temp: [], press: [], humid: [], mag_x: [], mag_y: [],
        mag_z: [], mag_r: [], acc_x: [], acc_y: [], acc_z: [], noise: [],
        gyros_x: [], gyros_y: [], gyros_z: [], light: [], x: [], y: [], z: []
      };
      this.lastQuery = query;
    }
    const req: any = {
      startTime: new Date(this.req.startTime).getTime(),
      endTime: new Date(this.req.endTime).getTime(),
      deviceNo: this.req.deviceNo,
      num: this.showNum ? this.req.num : null
    };
    this.req.parameter.map((item, index) => {
      req.parameter = item;
      this.getOne(req, index, this.req.parameter.length - 1, item);
    });
  }

  getOne(req, index, total, type) {
    this.isLoading = true;
    this.api.dataComparison.getDataComparisonForStepCiss([req, (data) => {
      const next = index !== total ? () => {} : () => {
        setTimeout(() => {
          this.isLoading = false;
        }, 3000);
      };
      if (data && data.lineDataVos && data.up && data.up.length > 0) {
        this.calc(data.lineDataVos, data.up, data.down, type, next);
      } else if (data && data.lineDataVos) {
        this.initNormalChart(data.lineDataVos, type, next);
      } else {
        this.message.error(data.message || this.translate.instant('checkIfHasData'));
        this.isLoading = false;
      }
    }]);
  }

  onChange(e) {
    if (e.sensorDeviceNo) {
      this.req.deviceNo = e.sensorDeviceNo;
      if (e.sensorType === 'CISS-Stepworking') {
        this.showNum = true;
      } else {
        this.showNum = false;
      }
    } else {
      this.showNum = false;
    }
  }

  calc(obj, max, min, type, next) {
    const series = [];
    const maxObj = [];
    const minObj = [];
    let last;
    max.map((item, index) => {
      maxObj.push([index, item]);
      minObj.push([index, min[index]]);
      if (obj[index] && index !== max.length - 1) {
        const red: any = {name: 'value', type: 'line', symbol: 'none', data: [], lineStyle: {normal: {color: '#FA0D09'}}};
        const normal: any = {
          name: 'value',
          type: 'line',
          symbol: 'none',
          data: [],
          lineStyle: {normal: {color: '#64BAFA'}}
        };
        if (index === 0) {
          last = obj[index] > item || obj[index] < min[index] ? red : normal;
        }
        if (obj[index] > item && obj[index + 1] < max[index + 1]) {
          // youshuangjiaocha
          const data = this.cross(obj[index], obj[index + 1], item, max[index + 1], index);
          last.data.push(data[0][0]);
          last.data.push({value: data[0][1], symbol: 'none', tooltip: {formatter: '-'}});
          series.push({...last});
          last = normal;
          last.data.push({value: data[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          if (obj[index + 1] < min[index + 1]) {
            const data2 = this.cross(obj[index], obj[index + 1], min[index], min[index + 1], index);
            last.data.push({value: data2[0][1], symbol: 'none', tooltip: {formatter: '-'}});
            series.push({...last});
            last = red;
            last.data.push({value: data2[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          }
        } else if (obj[index] < min[index] && obj[index + 1] > min[index + 1]) {
          // youshuangjiaocha
          const data = this.cross(obj[index], obj[index + 1], min[index], min[index + 1], index);
          last.data.push(data[0][0]);
          last.data.push({value: data[0][1], symbol: 'none', tooltip: {formatter: '-'}});
          series.push({...last});
          last = normal;
          last.data.push({value: data[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          if (obj[index + 1] > max[index + 1]) {
            const data2 = this.cross(obj[index], obj[index + 1], item, max[index + 1], index);
            last.data.push({value: data2[0][1], symbol: 'none', tooltip: {formatter: '-'}});
            series.push({...last});
            last = red;
            last.data.push({value: data2[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          }
        } else if (obj[index] > item && obj[index + 1] > max[index + 1]) {
          last.data.push([index, obj[index]]);
        } else if (obj[index] < min[index] && obj[index + 1] < min[index + 1]) {
          last.data.push([index, obj[index]]);
        } else if (obj[index] < item && obj[index + 1] > max[index + 1]) {
          // meiyoushuangjiaocha
          const data = this.cross(obj[index], obj[index + 1], item, max[index + 1], index);
          last.data.push(data[0][0]);
          last.data.push({value: data[0][1], symbol: 'none', tooltip: {formatter: '-'}});
          series.push({...last});
          last = red;
          last.data.push({value: data[1][0], symbol: 'none', tooltip: {formatter: '-'}});
        } else if (obj[index] > min[index] && obj[index + 1] < min[index + 1]) {
          // meiyoushuangjiaocha
          const data = this.cross(obj[index], obj[index + 1], min[index], min[index + 1], index);
          last.data.push(data[0][0]);
          last.data.push({value: data[0][1], symbol: 'none', tooltip: {formatter: '-'}});
          series.push({...last});
          last = red;
          last.data.push({value: data[1][0], symbol: 'none', tooltip: {formatter: '-'}});
        } else if (obj[index] < min[index] && obj[index + 1] > min[index + 1]) {
          // youshuangjiaocha
          const data = this.cross(obj[index], obj[index + 1], min[index], min[index + 1], index);
          last.data.push(data[0][0]);
          last.data.push({value: data[0][1], symbol: 'none', tooltip: {formatter: '-'}});
          series.push({...last});
          last = normal;
          last.data.push({value: data[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          if (obj[index + 1] > max[index + 1]) {
            const data2 = this.cross(obj[index], obj[index + 1], item, max[index + 1], index);
            last.data.push({value: data2[0][1], symbol: 'none', tooltip: {formatter: '-'}});
            series.push({...last});
            last = red;
            last.data.push({value: data2[1][0], symbol: 'none', tooltip: {formatter: '-'}});
          }
        } else {
          last.data.push([index, obj[index]]);
        }
      } else if (index === max.length - 1) {
        series.push({...last});
        this.initCharts(series, maxObj, minObj, type, next);
      }
    });
  }

  cross(po11, po12, po21, po22, num) {
    const n1 = po12 - po11;
    const n2 = po22 - po21;
    const c1 = po12 - n1 * (num + 1);
    const c2 = po22 - n2 * (num + 1);
    const x = ( c2 - c1 ) / ( n1 - n2 );
    const y = n1 * x + c1;
    return [[[num, po11], [x, y]], [[x, y], [num + 1, po12]]];
  }

  initNormalChart(data, type, next) {
    const len = data.length - 1;
    const obj = [];
    data.map((item, index) => {
      obj.push([index, item]);
      if (index === len) {
        const option: any = {...this.orOption};
        option.title.text = this.translate.instant(type) + this.translate.instant('data') + '(' + this.timeFormat(this.req.startTime)  + this.translate.instant('to')  + this.timeFormat(this.req.endTime) + ')';
        option.series = [{name: 'value', type: 'line', symbol: 'none', data: obj, lineStyle: {normal: {color: 'red'}}}];
        const length = this.optionQuery[type].length;
        this.optionQuery[type][length] = (option);
        next();
      }
    });
  }

  initCharts(obj, max, min, type, next) {
    const option = {...this.udOption};
    option.series[0].data = max;
    option.series[1].data = min;
    option.series = obj.concat(option.series);
    option.title.text = this.translate.instant(type) + this.translate.instant('data') + '(' + this.timeFormat(this.req.startTime)  + this.translate.instant('to')  + this.timeFormat(this.req.endTime) + ')';
    this.optionQuery[type].push(option);
    next();
  }

  add0(m) {
    return m < 10 ? '0' + m : m;
  }

  timeFormat(timestamp) {
    const time = new Date(timestamp);
    const year = time.getFullYear();
    const month = time.getMonth() + 1;
    const date = time.getDate();
    const hours = time.getHours();
    const minutes = time.getMinutes();
    const seconds = time.getSeconds();
    return year + '-' + this.add0(month) + '-' + this.add0(date) + ' ' + this.add0(hours) + ':' + this.add0(minutes) + ':' + this.add0(seconds);
  }

  onDateChange(type) {
    if (this.req.startTime && this.req.endTime && this.showNum) {
      if (new Date(this.req.endTime).getTime() < new Date(this.req.startTime).getTime()) {
        if (type) {
          this.message.error(this.translate.instant('startShouldLessThanEndTime'));
        }
      }
      if (new Date(this.req.endTime).getTime() - new Date(this.req.startTime).getTime() > 60 * 60 * 1000) {
        if (type) {
          this.message.error(this.translate.instant('searchTimeInOneHour'));
        }
      } else {
        this.isLoading = true;
        const req = {
          deviceNo: this.req.deviceNo,
          endTime: new Date(this.req.endTime).getTime(),
          startTime: new Date(this.req.startTime).getTime()
        };
        this.api.data.getCISSNum([req, (data) => {
          if (data && data.minNum && data.maxNum && new RegExp( '^[0-9]*$').test(data.minNum) && new RegExp( '^[0-9]*$').test(data.maxNum)) {
            this.num = [data.minNum + ' <=', '<= ' + data.maxNum];
          } else {
            const msg = this.translate.instant('checkIfSerialNumberExists');
            this.message.error(data.message || msg);
          }
          this.isLoading = false;
        }]);
      }
    }
  }

  onNumChange() {
    const num = parseInt(this.req.num, 10);
    const min = parseInt(this.num[0], 10);
    const max = parseInt(this.num[1], 10);
    if (isNaN(num) || num < 0) {
      this.req.num = '';
    } else if (num > max) {
      this.req.num = max;
    } else if (num < min) {
      this.req.min = min;
    } else {
      this.req.num = num;
    }
  }

  numAdd() {
    const num = parseInt(this.req.num, 10);
    const min = parseInt(this.num[0], 10);
    const max = parseInt(this.num[1], 10);
    if (isNaN(num) || num + 1 < 0) {
      this.req.num = 1;
    } else if (num + 1 > max) {
      this.req.num = max;
    } else if (num + 1 < min) {
      this.req.min = min;
    } else {
      this.req.num = num + 1;
    }
  }

  numDel() {
    const num = parseInt(this.req.num, 10);
    const min = parseInt(this.num[0], 10);
    const max = parseInt(this.num[1], 10);
    if (isNaN(num) || num - 1 < 0) {
      this.req.num = 0;
    } else if (num - 1 > max) {
      this.req.num = max;
    } else if (num - 1 < min) {
      this.req.min = min;
    } else {
      this.req.num = num - 1;
    }
  }
}
