import { Component, OnInit } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { CheckService } from '../../shared/service/check.service';
import { NzMessageService, NzModalService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import { PermissionService } from '../../shared/service/permission.service';
import { NzTreeNode } from 'ng-zorro-antd';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-collector-manage',
  templateUrl: './collector-manage.component.html',
  animations: [fadeIn],
  styles: [`
    :host::ng-deep .cdk-overlay-pane {
      height: 300px;
      overflow-y: auto;
    }
  `]
})
export class CollectorManageComponent implements OnInit {

  req: any = {};
  req2: any = {};
  data: any = [];
  isLoading = false;
  isVisible = false;
  isVisible2 = false;
  isUpdate = false;
  sensorName = '';
  areas = [];
  models = [];
  types = [];
  alarms = [];
  gateways = [];
  isVisible3 = false;
  req3: any = {};
  points = [];
  isVisible4 = false;
  req4: any = {};
  factorys = [];
  constructor(private api: ApiService, private message: NzMessageService, private translate: TranslateService,
              private modalService: NzModalService, private ck: CheckService, public per: PermissionService) { }

  ngOnInit() {
    this.init();
  }

  init() {
    this.getData();
    this.getAreas();
    this.getDeviceModels();
    this.getDeviceTypes();
    this.getAlarms();
    this.getAllGateway();
    this.getPoints();
    this.getFactorys();
  }

  getFactorys() {
    this.isLoading = true;
    this.api.factory.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.initFactorys(data);
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  initFactorys(data) {
    const nodes = [];
    if (data && data.length > 0) {
      data.map((one, index) => {
        let obj: any = {};
        if (one.resultFactoryAreaVo && one.resultFactoryAreaVo.factoryNo) {
          obj = {
            value: one.resultFactoryAreaVo.factoryNo,
            key: one.resultFactoryAreaVo.factoryNo,
            title: one.resultFactoryAreaVo.factoryName
          };
          if (one.resultFactoryDepartmentVos && one.resultFactoryDepartmentVos.length > 0) {
            obj.children = [];
          }
        }
        if (one.resultFactoryDepartmentVos && one.resultFactoryDepartmentVos.length > 0) {
          one.resultFactoryDepartmentVos.map((two, tIndex) => {
            if (!(one.resultFactoryAreaVo || one.resultFactoryAreaVo.factoryNo) && tIndex === 0 && two.resultFactoryDepartmentVo && two.resultFactoryDepartmentVo.factoryNo) {
              obj = {
                value: two.resultFactoryDepartmentVo.factoryNo,
                key: two.resultFactoryDepartmentVo.factoryNo,
                title: two.resultFactoryDepartmentVo.factoryName
              };
              if (two.resultFactoryLineVos && two.resultFactoryLineVos.length > 0) {
                obj.children = [];
              }
            } else {
              if (two.resultFactoryDepartmentVo && two.resultFactoryDepartmentVo.factoryNo) {
                obj.children.push({
                  value: two.resultFactoryDepartmentVo.factoryNo,
                  key: two.resultFactoryDepartmentVo.factoryNo,
                  title: two.resultFactoryDepartmentVo.factoryName
                });
                if (two.resultFactoryLineVos && two.resultFactoryLineVos.length > 0) {
                  obj.children[tIndex].children = [];
                }
              }
            }
            if (two.resultFactoryLineVos && two.resultFactoryLineVos.length > 0) {
              two.resultFactoryLineVos.map((three, hIndex) => {
                if (!(one.resultFactoryAreaVo || one.resultFactoryAreaVo.factoryNo) && !(two.resultFactoryDepartmentVo || two.resultFactoryDepartmentVo.factoryNo)) {
                  obj.children.push({
                    value: three.factoryNo,
                    key: three.factoryNo,
                    title: three.factoryName
                  });
                } else if (!(one.resultFactoryAreaVo || one.resultFactoryAreaVo.factoryNo) && two.resultFactoryDepartmentVo && two.resultFactoryDepartmentVo.factoryNo) {
                  obj.children.push({
                    value: three.factoryNo,
                    key: three.factoryNo,
                    title: three.factoryName
                  });
                } else {
                  obj.children[tIndex].children.push({
                    value: three.factoryNo,
                    key: three.factoryNo,
                    title: three.factoryName
                  });
                }
                if (hIndex === two.resultFactoryLineVos.length - 1 && tIndex === one.resultFactoryDepartmentVos.length - 1) {
                  nodes.push(new NzTreeNode(obj));
                }
                if (hIndex === two.resultFactoryLineVos.length - 1 && tIndex === one.resultFactoryDepartmentVos.length - 1 && index === data.length - 1) {
                  this.factorys = nodes;
                }
              });
            } else if (tIndex === one.resultFactoryDepartmentVos.length - 1 && index === data.length - 1) {
              nodes.push(new NzTreeNode(obj));
              this.factorys = nodes;
            } else {
              if (tIndex === one.resultFactoryDepartmentVos.length - 1) {
                nodes.push(new NzTreeNode(obj));
              }
            }
          });
        } else if (index === data.length - 1) {
          nodes.push(new NzTreeNode(obj));
          this.factorys = nodes;
        } else {
          nodes.push(new NzTreeNode(obj));
        }
      });
    }
  }

  onTreeClick(e) {
    this.req.factoryNo = e.node.key;
  }

  onClear() {
    this.req.factoryNo = {};
  }

  getPoints() {
    this.isLoading = true;
    this.api.monitoringPoint.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.points = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getAllGateway() {
    this.isLoading = true;
    this.api.gateway.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.gateways = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getDeviceModels() {
    this.isLoading = true;
    this.api.deviceModel.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.models = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getAlarms() {
    this.isLoading = true;
    this.api.alarm.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.alarms = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getDeviceTypes() {
    this.isLoading = true;
    this.api.deviceType.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.types = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getAreas() {
    this.isLoading = true;
    this.api.factory.getAllForFactoryLine(['', (data) => {
      if (data.constructor === Array) {
        this.areas = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getData() {
    this.isLoading = true;
    this.api.sensor.getAll(['', this.next]);
  }

  next = (data) => {
    if (data.constructor === Array) {
      this.data = data;
    } else if (data.code === 1) {
      this.message.success(data.message || this.translate.instant('operateSuccess'));
      this.isVisible = false;
      this.isVisible2 = false;
      this.isVisible3 = false;
      this.isVisible4 = false;
      this.init();
    } else if (data.code === 0) {
      this.message.error(data.message || this.translate.instant('operateFail'));
    } else {
      this.message.error(data.message || this.translate.instant('wrongToGetData'));
    }
    this.isLoading = false;
  }

  add() {
    this.isUpdate = false;
    this.req = {};
    this.isVisible = true;
  }

  edit(item) {
    this.isUpdate = true;
    this.req = {...item};
    this.isVisible = true;
  }

  cancel() {
    this.isVisible = false;
  }

  save() {
    this.isLoading = true;
    const req = {...this.req};
    const check = this.isUpdate ? {field: ['sensorName']} : {field: ['deviceType', 'deviceModel', 'sensorName', 'sensorSN']};
    if (!this.ck.formCheck(req, check)) {
      this.isLoading = false;
      return;
    }
    if (this.isUpdate) {
      this.api.sensor.updateSensor([req, this.next]);
    } else {
      this.api.sensor.addSensor([req, this.next]);
    }
  }

  deleteConfirm(one) {
    this.modalService.confirm({
      nzTitle  : '<i></i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteThisRecord') + '</b>',
      nzOnOk   : () => this.delete(one)
    });
  }

  delete(one) {
    this.isLoading = true;
    const req = {deviceNo: one.sensorDeviceNo};
    this.api.sensor.deleteSensor([req, this.next]);
  }

  unbindConfirm(one) {
    this.modalService.confirm({
      nzTitle  : '<i></i>',
      nzContent: '<b>' + this.translate.instant('confirmUnbindGateway') + '</b>',
      nzOnOk   : () => this.unbind(one)
    });
  }

  unbindPointConfirm(one) {
    this.modalService.confirm({
      nzTitle  : '<i></i>',
      nzContent: '<b>' + this.translate.instant('confirmUnbindMonitoringPoint') + '</b>',
      nzOnOk   : () => this.unbindPoint(one)
    });
  }

  unbindPoint(one) {
    this.isLoading = false;
    const req = {
      monitoringPointNo: one.monitoringPointNo,
      sensorDeviceNos: [one.sensorDeviceNo]
    };
    this.api.sensor.unbindSensorAndMonitoringPoint([req, this.next]);
  }

  query() {
    this.isLoading = true;
    const req = {
      sensorName: this.sensorName
    };
    this.api.sensor.getByTerm([req, this.next]);
  }

  onSearch() {
    this.query();
  }

  onGetAll() {
    this.sensorName = '';
    this.getData();
  }

  bind(one) {
    this.isVisible2 = true;
    this.req2.sensorDeviceNo = one.sensorDeviceNo;
    this.req2.gatewayDeviceNo = '';
  }

  unbind(one) {
    const req = [one.sensorDeviceNo];
    this.api.sensor.unBindSensor([req, this.next]);
  }

  cancel2() {
    this.isVisible2 = false;
  }

  save2() {
    this.isLoading = true;
    const req = {
      gatewayDeviceNo: this.req2.gatewayDeviceNo,
      sensorDeviceNos: [this.req2.sensorDeviceNo]
    };
    this.api.sensor.bindSensor([req, this.next]);
  }

  bindPoint(one) {
    this.req3 = {};
    this.req3.sensorDeviceNo = one.sensorDeviceNo;
    this.isVisible3 = true;
  }

  cancel3() {
    this.isVisible3 = false;
  }

  save3() {
    this.isLoading = true;
    const req = {
      alarmNos: [this.req3.alarmNo],
      monitoringPointNo: this.req3.monitoringPointNo,
      sensorDeviceNos: [this.req3.sensorDeviceNo],
      xaxis: ['0'],
      yaxis: ['0']
    };
    this.api.sensor.bindSensorAndMonitoringPoint([req, this.next]);
  }

  divide(one) {
    this.req4 = {};
    this.req4.sensorDeviceNo = one.sensorDeviceNo;
    this.isVisible4 = true;
  }

  cancel4() {
    this.isVisible4 = false;
  }

  save4() {
    this.isLoading = true;
    const req = {
      factoryNo: this.req4.factoryNo,
      sensorDeviceNo: this.req4.sensorDeviceNo
    };
    this.api.sensor.updateSensorFactory([req, this.next]);
  }

  onTypeChange() {
    if (this.req.deviceType === 'XDK') {
      this.req.deviceModel = '------';
    }
  }
}

