import {Component, OnInit, OnDestroy} from '@angular/core';
import {ActivatedRoute} from '@angular/router';
import {NzMessageService, NzModalService} from 'ng-zorro-antd';
import {fadeIn} from '../../animation/fade-in';
import {ApiService} from '../../shared/service/api.service';
import {PermissionService} from '../../shared/service/permission.service';
import * as echarts from 'echarts';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-cutting-machine-detail',
  templateUrl: './cutting-machine-detail.component.html',
  styleUrls: ['./cutting-machine-detail.component.scss'],
  animations: [fadeIn]
})
export class CuttingMachineDetailComponent implements OnInit, OnDestroy {
  alarmData = [];
  req: any = {};
  timeData = [{label: 'lastWeek', value: 168}, {label: 'lastHalfMonth', value: 360}, {label: 'lastMonth', value: 720}];
  isLoading = false;
  isVisible = false;
  alarmCharts = [];
  alarmChart = {
    title: {
      text: '',
      left: '5%',
      top: '3%'
    },
    tooltip: {
      trigger: 'axis',
      formatter: (value) => {
        return value[0].data[1];
      }
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      containLabel: true
    },
    dataZoom: [
      {
        show: true,
        start: 0,
        end: 100,
        xAxisIndex: 0
      }
    ],
    xAxis: {
      type: 'value'
    },
    yAxis: {
      type: 'value'
    },
    series: [
      {
        name: '',
        type: 'line',
        data: [],
        symbol: 'none',
      }
    ]
  };
  option1 = {
    // tooltip: {
    //   formatter: "{a} <br/>{b} : {c}"
    // },
    series: [{
      type: 'gauge',
      radius: 90,
      startAngle: 315,
      endAngle: 45,
      center: ['50%', '50%'],
      axisLine: {
        show: true,
        lineStyle: {
          width: 15,
          color: [
            [0, '#36ce9b'],
            [1, '#576d85']
          ]
        }
      },
      splitLine: {
        show: false,
      },
      axisTick: {
        show: false,
      },
      axisLabel: {
        show: false,
      },
      pointer: {
        show: false,
        length: '90%',
        width: 3,
      },
      title: {
        show: true,
        offsetCenter: [40, 0],
        textStyle: {
          color: '#36ce9b',
          fontSize: 16
        }
      },
      detail: {
        show: false
      },
      data: [{
        value: 0,
        name: '',
      }]
    }]
  };
  option2 = {
    title: {
      text: '',
      left: '0',
      top: '3%'
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      containLabel: true
    },
    xAxis: {
      data: [],
      axisLabel: {
        inside: true,
        textStyle: {
          color: '#fff'
        }
      },
      axisTick: {
        show: true
      },
      axisLine: {
        show: true
      },
      z: 10
    },
    yAxis: {
      axisLine: {
        show: true
      },
      axisTick: {
        show: true
      },
      axisLabel: {
        textStyle: {
          color: '#999'
        }
      }
    },
    series: [
      { // For shadow
        type: 'bar',
        itemStyle: {
          normal: {color: 'rgba(0,0,0,0.05)'}
        },
        barGap: '-100%',
        barCategoryGap: '40%',
        animation: false
      },
      {
        type: 'bar',
        itemStyle: {
          normal: {
            color: new echarts.graphic.LinearGradient(
              0, 0, 0, 1,
              [
                {offset: 0, color: '#83bff6'},
                {offset: 0.5, color: '#188df0'},
                {offset: 1, color: '#188df0'}
              ]
            )
          },
          emphasis: {
            color: new echarts.graphic.LinearGradient(
              0, 0, 0, 1,
              [
                {offset: 0, color: '#2378f7'},
                {offset: 0.7, color: '#2378f7'},
                {offset: 1, color: '#83bff6'}
              ]
            )
          }
        },
        data: []
      }
    ]
  };
  optionOther = {
    title: {
      text: ''
    },
    tooltip: {
      trigger: 'axis'
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '8%',
      containLabel: true
    },
    dataZoom: [
      {
        type: 'slider',
        show: true,
        start: 0,
        end: 100
      },
      {
        type: 'inside',
        start: 0,
        end: 100
      }
    ],
    xAxis: {
      type: 'category',
      data: [],
      axisLabel: {
        textStyle: {
          color: '#000000'
        }
      },
      axisTick: {
        show: true
      },
      axisLine: {
        show: true
      },
      z: 10
    },
    yAxis: {
      type: 'value'
    },
    series: [
      {
        name: '',
        type: 'line',
        symbol: 'none',
        data: []
      }
    ]
  };
  // chartOther1: any = {};
  chartOther2: any = {};
  chartOther3: any = {};
  monitoringPointNo = '';
  monitoringPointName = '';
  sensorSN = '';
  sensor = '';
  data: any = {};
  isLoading2 = false;
  _inv;

  constructor(public per: PermissionService, private api: ApiService, private modal: NzModalService,
              private message: NzMessageService, private acRouter: ActivatedRoute, private translate: TranslateService) {
  }

  ngOnInit() {
    this.acRouter.queryParams.subscribe((params) => {
      if (params.monitoringPointNo) {
        this.monitoringPointName = params.monitoringPointName;
        this.monitoringPointNo = params.monitoringPointNo;
        this.sensorSN = params.sensorSN;
        this.getData();
        this.req.startTime = new Date().getTime();
        this.req.selectTime = 168;
        this.req.selectTime2 = 168;
        this.req.selectTime3 = 1;
        this.getAlarmData();
        this.getChartsData();
        if (params.sensorSN) {
          this._inv = setInterval(() => {
            this.refreshData();
          }, 60000);
          this.getCharts2Data();
        } else {
          const option = JSON.parse(JSON.stringify(this.optionOther));
          // option.title.text = this.monitoringPointName + ' ' + this.translate.instant('testResultAveLineChart');
          // this.chartOther1 = JSON.parse(JSON.stringify(option));
          option.title.text = this.monitoringPointName + ' ' + this.translate.instant('onceTestResultLineChart');
          this.chartOther3 = JSON.parse(JSON.stringify(option));
          option.title.text = this.monitoringPointName + ' ' + this.translate.instant('testPercentLineChart');
          this.chartOther2 = JSON.parse(JSON.stringify(option));
        }
      }
    });
  }

  ngOnDestroy() {
    window.clearInterval(this._inv);
  }

  onSearch() {
    this.getChartsData();
  }

  onLineSearch() {
    window.clearInterval(this._inv);
    if (Number(this.req.selectTime3) === 1) {
      this._inv = setInterval(() => {
        this.refreshData();
      }, 60000);
    }
    this.getCharts2Data();
  }

  refreshData() {
    const option = JSON.parse(JSON.stringify(this.chartOther2));
    const x = option.xAxis.data;
    const obj = option.series[0].data || [];
    const req = {
      endTime: new Date().getTime(),
      monitoringPointNo: this.monitoringPointNo,
      sensorSN: this.sensorSN,
      offset: 0 - new Date().getTimezoneOffset() / 60,
      startTime: new Date().getTime() - 60000
    };
    this.api.analysis.getCuttingMachineDetailForData([req, (data) => {
      if (data.constructor === Array) {
        const len = data.length - 1;
        if (data.length > 0) {
          data.map((item, index) => {
            if (Number(item.refValue) >= 0) {
              x.push(this.transTime(item.time - 0));
              obj.push(Number(item.avgRefValue));
            }
            if (index === len) {
              option.series[0].data = obj;
              option.xAxis.data = x;
              this.chartOther2 = JSON.parse(JSON.stringify(option));
            }
          });
        }
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getData() {
    this.isLoading = true;
    const req = this.sensorSN ? {
      monitoringPointNo: this.monitoringPointNo,
      sensorSN: this.sensorSN
    } : {
      monitoringPointNo: this.monitoringPointNo
    };
    this.api.analysis.getCuttingMachineDetail([req, (data) => {
      if (data && data.monitoringPointNo) {
        this.data = data;
        const option = {...this.option1};
        if (Number(data.totalNum) > 10000) {
          option.series[0].title.textStyle = {
            color: '#f5222d',
            fontSize: 16
          };
          option.series[0].axisLine.lineStyle.color = [
            [(parseFloat(data.totalNum) / (parseFloat(data.remainNum) + parseFloat(data.totalNum))).toFixed(2), '#f5222d'],
            [1, '#576d85']];
        } else {
          option.series[0].axisLine.lineStyle.color = [
            [(parseFloat(data.totalNum) / (parseFloat(data.remainNum) + parseFloat(data.totalNum))).toFixed(2), '#36ce9b'],
            [1, '#576d85']];
        }
        option.series[0].data = [{
          value: parseFloat(data.totalNum),
          name: this.translate.instant('nowKnifeUsed') + ' ' + data.totalNum + ' ' + this.translate.instant('times') + '\n\n' + this.translate.instant('maybeUsed') + ' ' + data.remainNum + ' ' + this.translate.instant('times'),
        }];
        this.option1 = option;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getChartsData() {
    this.isLoading = true;
    const req = {
      monitoringPointNo: this.monitoringPointNo,
      sensorSN: this.sensorSN,
      endTime: new Date().getTime(),
      startTime: new Date().getTime() - Number(this.req.selectTime) * 3600 * 1000
    };
    this.api.analysis.getCuttingMachineDetailForKnife([req, (data) => {
      if (data.constructor === Array) {
        this.initChart(data);
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getCharts2Data() {
    this.isLoading = true;
    this.isLoading2 = true;
    const req = {
      endTime: new Date().getTime(),
      monitoringPointNo: this.monitoringPointNo,
      sensorSN: this.sensorSN,
      offset: 0 - new Date().getTimezoneOffset() / 60,
      startTime: new Date().getTime() - Number(this.req.selectTime3) * 3600 * 1000
    };
    this.api.analysis.getCuttingMachineDetailForData([req, (data) => {
      if (data.constructor === Array) {
        this.initChart2(data);
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  initChart(data) {
    const option = JSON.parse(JSON.stringify(this.option2));
    const dataArr = [];
    const xAxisArr = [];
    if (data.length > 0) {
      data.map((item, index) => {
        xAxisArr.push(this.translate.instant('knife') + item.knifenum);
        dataArr.push(item.totalNum);
        if (index === data.length - 1) {
          option.series[1].data = dataArr;
          option.xAxis.data = xAxisArr;
          option.title.text = this.monitoringPointName + ' ' + this.translate.instant('allKnifeAllTimesInOneMonth');
          this.option2 = option;
        }
      });
    } else {
      option.title.text = this.monitoringPointName + ' ' + this.translate.instant('allKnifeAllTimesInOneMonth');
      this.option2 = option;
    }
  }

  initChart2(data) {
    const option: any = JSON.parse(JSON.stringify(this.optionOther));
    const dataArr1 = [];
    const dataArr2 = [];
    const dataArr3 = [];
    const xAxis = [];
    const series: any = {};
    series.type = 'line';
    series.symbol = 'none';
    series.lineStyle = {};
    const len = data.length - 1;
    if (data.length > 0) {
      data.map((item, index) => {
        if (Number(item.refValue) >= 0) {
          xAxis.push(this.transTime(item.time - 0));
          dataArr1.push(Number(item.avgResValue));
          dataArr2.push(Number(item.avgRefValue));
          if (item.resValue !== 'GOOD') {
            dataArr3.push({
              symbol: 'circle',
              symbolSize: 7,
              value: Number(item.refValue),
              itemStyle: {color: '#ff4d4f'}
            });
          } else {
            dataArr3.push({value: Number(item.refValue)});
          }
        }
        if (index === len) {
          option.visualMap = {
            top: 10,
            right: 10,
            show: false,
            pieces: [{
              gt: -0.01,
              lte: 0.5,
              color: '#f5222d'
            }, {
              gt: 0.5,
              lte: 0.8,
              color: '#ffde33'
            }],
            outOfRange: {
              color: '#1890ff'
            }
          };
          option.series.markLine = {
            silent: true,
            data: [{
              yAxis: 0.5
            }, {
              yAxis: 0.8
            }]
          };
          option.title.text = this.monitoringPointName + ' ' + this.translate.instant('testPercentLineChart');
          series.name = this.translate.instant('testPercent');
          series.data = dataArr2;
          option.series = [series];
          option.xAxis.data = xAxis;
          this.chartOther2 = JSON.parse(JSON.stringify(option));
          option.title.text = this.monitoringPointName + ' ' + this.translate.instant('onceTestResultLineChart');
          series.name = this.translate.instant('onceTestResult');
          series.data = dataArr3;
          option.series = [series];
          option.xAxis.data = xAxis;
          this.chartOther3 = JSON.parse(JSON.stringify(option));
          this.isLoading2 = false;
        }
      });
    } else {
      // option.title.text = this.translate.instant('testResultAveLineChart');
      // this.chartOther1 = JSON.parse(JSON.stringify(option));
      option.title.text = this.monitoringPointName + ' ' + this.translate.instant('onceTestResultLineChart');
      this.chartOther3 = JSON.parse(JSON.stringify(option));
      option.title.text = this.monitoringPointName + ' ' + this.translate.instant('testPercentLineChart');
      this.chartOther2 = JSON.parse(JSON.stringify(option));
      this.isLoading2 = false;
    }
  }

  getAlarmData() {
    this.isLoading = true;
    const req = {
      monitoringPointNo: this.monitoringPointNo,
      endTime: new Date().getTime(),
      startTime: new Date().getTime() - Number(this.req.selectTime2) * 3600 * 1000
    };
    this.api.analysis.getCuttingMachineDetailForAlarm([req, (data) => {
      if (data.constructor === Array) {
        this.alarmData = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  onAlarmSearch() {
    if (!this.req.selectTime2) {
      this.message.error(this.translate.instant('pleaseChooseRightAlarmTime'));
    } else {
      this.getAlarmData();
    }
  }

  getAlarmDetail(one) {
    this.isLoading = true;
    const req = {
      alarmLogNo: one.alarmLogNo,
      endTime: new Date(one.alarmTime - 0).getTime() + 150 * 1000,
      offset: 0 - new Date().getTimezoneOffset() / 60,
      startTime: new Date(one.alarmTime - 0).getTime() - 150 * 1000
    };
    this.api.analysis.getCuttingMachineDetailForAlarmDetail([req, (data) => {
      if (data && data.resultSensorVo) {
        if (data.x && data.x.lineDataVos) {
          this.initAlarmChart('x', data.resultSensorVo, data.x.lineDataVos, 0);
        } else {
          this.initAlarmChart('x', {}, [], 0);
        }
        if (data.y && data.y.lineDataVos) {
          this.initAlarmChart('y', data.resultSensorVo, data.y.lineDataVos, 1);
        } else {
          this.initAlarmChart('y', {}, [], 1);
        }
        if (data.z && data.z.lineDataVos) {
          this.initAlarmChart('z', data.resultSensorVo, data.z.lineDataVos, 2);
        } else {
          this.initAlarmChart('z', {}, [], 2);
        }
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
    }]);
  }

  initAlarmChart(type, cont, data, index) {
    const dataArr = [];
    const option = JSON.parse(JSON.stringify(this.alarmChart));
    const len = data.length - 1;
    if (data.length > 0) {
      data.map((item, num) => {
        dataArr.push([num, item.data]);
        if (num === len) {
          option.series[0].name = cont.sensorSN + this.translate.instant('data');
          option.series[0].data = dataArr;
          option.title.text = this.monitoringPointName + ' ' + type + this.translate.instant('data');
          const obj = JSON.parse(JSON.stringify(this.alarmCharts));
          obj[index] = option;
          this.alarmCharts = obj;
          if (index === 2) {
            this.isVisible = true;
            this.isLoading = false;
          }
        }
      });
    } else {
      option.title.text = this.monitoringPointName + ' ' + type + this.translate.instant('data');
      const obj = JSON.parse(JSON.stringify(this.alarmCharts));
      obj[index] = option;
      this.alarmCharts = obj;
      if (index === 2) {
        this.isVisible = true;
        this.isLoading = false;
      }
    }
  }

  cancel() {
    this.isVisible = false;
    this.alarmCharts = [];
  }

  showDispose(one) {
    this.modal.confirm({
      nzTitle: this.translate.instant('operateTips'),
      nzContent: '<b>' + this.translate.instant('confirmDeleteThisKnifeBroken') + '</b>',
      nzOnOk: () => this.disposeAlarm(one)
    });
  }

  disposeAlarm(one) {
    this.isLoading = true;
    const req = {alarmLogNo: one.alarmLogNo};
    this.api.analysis.getCuttingMachineDetailForDisposeAlarm([req, (data) => {
      if (data.code === 1) {
        this.getAlarmData();
        this.message.success(data.message || this.translate.instant('operateSuccess'));
      } else {
        this.message.error(data.message || this.translate.instant('operateFail'));
      }
      this.isLoading = false;
    }]);
  }

  public transTime(value, type?) {
    if (!(value - 0) || isNaN(value - 0)) {
      return this.translate.instant(value);
    }
    if (value.length === 10) {
      value = value * 1000;
    }
    const date: any = new Date(value - 0);
    const texts = [date.getFullYear(), this.addZero(date.getMonth() + 1), this.addZero(date.getDate())];
    const time = [this.addZero(date.getHours()), this.addZero(date.getMinutes()), this.addZero(date.getSeconds())];
    const ref = type ? texts.join('-') + '\n' + time.join(':') : texts.join('-') + ' ' + time.join(':');
    return ref;
  }

  private addZero(date) {
    if (date.toString().length === 1) {
      date = '0' + date.toString();
    }
    return date;
  }
}
