import { Component, OnInit } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { CheckService } from '../../shared/service/check.service';
import { NzMessageService, NzModalService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import { PermissionService } from '../../shared/service/permission.service';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-department-manage',
  templateUrl: './department-manage.component.html',
  animations: [fadeIn],
  styles: []
})

export class DepartmentManageComponent implements OnInit {
  req: any = {};
  data: any = [];
  isLoading = false;
  isVisible = false;
  isUpdate = false;
  nzOptions: any = {};
  area: any;
  roles = [];
  factorys = [];
  constructor(private api: ApiService, private message: NzMessageService, private translate: TranslateService,
              private modalService: NzModalService, private ck: CheckService, public per: PermissionService) { }

  ngOnInit() {
    this.init();
  }

  init() {
    this.getData();
    this.getFactorys();
    this.getRoles();
  }

  getRoles() {
    this.isLoading = true;
    this.api.role.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.roles = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
    }]);
  }

  getFactorys() {
    this.isLoading = false;
    this.api.factory.getAllForFactoryArea(['', (data) => {
      if (data.constructor === Array) {
        this.factorys = data.filter((item) => item.factoryNo !== 'FN27276861545783296');
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
    }]);
  }

  getData() {
    this.isLoading = true;
    this.api.factory.getAllForDepartment(['', this.next]);
  }

  next = (data) => {
    if (data.constructor === Array) {
      this.data = data;
    } else if (data.code === 1) {
      this.message.success(data.message || this.translate.instant('operateSuccess'));
      this.isVisible = false;
      this.init();
    } else if (data.code === 0) {
      this.message.error(data.message || this.translate.instant('operateFail'));
    } else {
      this.message.error(data.message || this.translate.instant('wrongToGetData'));
    }
    this.isLoading = false;
  }

  add() {
    this.isUpdate = false;
    this.req = {};
    this.isVisible = true;
  }

  edit(item) {
    this.isUpdate = true;
    this.req = {...item};
    this.isVisible = true;
  }

  cancel() {
    this.isVisible = false;
  }

  save() {
    this.isLoading = true;
    const req: any = {...this.req};
    const check = {
      field: this.isUpdate ? ['parentFactoryNo', 'factoryName'] : ['parentFactoryNo', 'factoryName', 'roleNo'],
      tel: ['phone']
    };
    if (!this.ck.formCheck(req, check)) {
      this.isLoading = false;
      return;
    }
    if (this.isUpdate) {
      this.api.factory.updateFactoryLine([req, this.next]);
    } else {
      this.api.factory.addFactoryDepartment([req, this.next]);
    }
  }

  deleteConfirm(one) {
    this.modalService.confirm({
      nzTitle  : '<i></i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteThisRecord') + '</b>',
      nzOnOk   : () => this.delete(one)
    });
  }

  delete(one) {
    this.isLoading = true;
    const req = {factoryNo: one.factoryNo};
    this.api.factory.deleteFactory([req, this.next]);
  }
}

