import { Component, OnInit } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { CheckService } from '../../shared/service/check.service';
import { NzMessageService, NzModalService } from 'ng-zorro-antd';
import { Router } from '@angular/router';
import { fadeIn } from '../../animation/fade-in';
import { PermissionService } from '../../shared/service/permission.service';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-device-type',
  templateUrl: './device-type.component.html',
  animations: [fadeIn],
  styles: []
})
export class DeviceTypeComponent implements OnInit {

  req: any = {};
  data: any = [];
  isLoading = false;
  isVisible = false;
  isUpdate = false;
  name = '';
  constructor(private api: ApiService, private message: NzMessageService, private translate: TranslateService,
              private modalService: NzModalService, private ck: CheckService, public per: PermissionService) { }

  ngOnInit() {
    this.init();
  }

  init() {
    this.getData();
  }

  getData() {
    this.isLoading = true;
    this.api.deviceType.getAll(['', this.next]);
  }

  next = (data) => {
    if (data.constructor === Array) {
      this.data = data;
    } else if (data.code === 1) {
      this.message.success(data.message || this.translate.instant('operateSuccess'));
      this.isVisible = false;
      this.init();
    } else if (data.code === 0) {
      this.message.error(data.message || this.translate.instant('operateFail'));
    } else {
      this.message.error(data.message || this.translate.instant('wrongToGetData'));
    }
    this.isLoading = false;
  }

  add() {
    this.isUpdate = false;
    this.req = {};
    this.isVisible = true;
  }

  edit(item) {
    this.isUpdate = true;
    this.req = {...item};
    this.req.oldDeviceType = item.deviceType;
    this.isVisible = true;
  }

  cancel() {
    this.isVisible = false;
  }

  save() {
    this.isLoading = true;
    const req = {...this.req};
    const check = {
      field: ['deviceType']
    };
    if (!this.ck.formCheck(req, check)) {
      this.isLoading = false;
      return;
    }
    if (this.isUpdate) {
      this.api.deviceType.updateDeviceType([req, this.next]);
    } else {
      this.api.deviceType.addDeviceType([req, this.next]);
    }
  }

  deleteConfirm(one) {
    this.modalService.confirm({
      nzTitle  : '<i></i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteThisRecord') + '</b>',
      nzOnOk   : () => this.delete(one)
    });
  }

  delete(one) {
    this.isLoading = true;
    const req = {deviceType: one.deviceType};
    this.api.deviceType.deleteDeviceType([req, this.next]);
  }

  query() {
    this.isLoading = true;
    const req = {deviceModel: this.name};
    this.api.deviceType.getByDeviceTypeForLike([req, this.next]);
  }

  onSearch() {
    this.query();
  }

  onGetAll() {
    this.getData();
    this.name = '';
  }
}
