import { Component, OnInit, ElementRef, EventEmitter, HostListener, Input, Output } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { isUndefined } from 'util';
import { NzMessageService } from 'ng-zorro-antd';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-drag',
  templateUrl: './drag.component.html',
  styles: []
})
export class DragComponent implements OnInit {

  constructor(public el: ElementRef, private api: ApiService,
              private translate: TranslateService, private message: NzMessageService) { }
  @Input()
  type = '';
  @Input()
  xMax = 0;
  @Input()
  yMax = 0;
  _data: any;
  @Input()
  get data() {
    return this._data;
  }
  set data(_data) {
    this._data = _data;
    this.initPosition();
  }
  public isDown = false;
  public disX;
  public disY;

  private totalOffsetX = 0;
  private totalOffsetY = 0;

  @HostListener('mousedown', ['$event']) onMousedown(event) {
    if (this.type !== 'home' && !this.isDown) {
      this.isDown = true;
      this.disX = event.clientX;
      this.disY = event.clientY;
    }
  }

  @HostListener('document:mousemove', ['$event']) onMousemove(event) {
    if (this.isDown && this.type !== 'home') {
      if (this.totalOffsetX + event.clientX - this.disX < this.xMax && this.totalOffsetX + event.clientX - this.disX > 0) {
        this.el.nativeElement.style.left = this.totalOffsetX + event.clientX - this.disX + 'px';
      }
      if (this.totalOffsetY + event.clientY - this.disY < this.yMax && this.totalOffsetY + event.clientY - this.disY > 0) {
        this.el.nativeElement.style.top = this.totalOffsetY + event.clientY - this.disY + 'px';
      }
    }
  }

  @HostListener('document:mouseup', ['$event']) onMouseup(event) {
    if (this.isDown && this.type !== 'home') {
      this.totalOffsetX += event.clientX - this.disX;
      this.totalOffsetY += event.clientY - this.disY;
      this.isDown = false;
      this.updatePosition();
    }
  }

  updatePosition() {
    if (this.type !== 'home') {
      const req: any = {...this._data};
      req.xaxis = this.el.nativeElement.style.left;
      req.yaxis = this.el.nativeElement.style.top;
      if (this.type === 'factory') {
        this.api.monitoringPoint.updateMonitoringPoint([req, (data) => {
          if (data.code === 0 || !data || isUndefined(data.code)) {
            this.message.error(data.message || this.translate.instant('operateFail'));
          }
        }]);
      } else {
        this.api.sensor.updateSensor([req, (data) => {
          if (data.code === 0 || !data || isUndefined(data.code)) {
            this.message.error(data.message || this.translate.instant('operateFail'));
          }
        }]);
      }
    }
  }

  initPosition() {
    setTimeout(() => {
      this.el.nativeElement.style.left = this._data.x + 'px';
      this.el.nativeElement.style.top = this._data.y + 'px';
      if (this.type !== 'home') {
        this.totalOffsetX = this._data.x;
        this.totalOffsetY = this._data.y;
      }
    });
  }

  ngOnInit() {
    this.el.nativeElement.style.position = 'absolute';
  }
}
