import { Component, OnInit } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { CheckService } from '../../shared/service/check.service';
import { NzMessageService, NzModalService } from 'ng-zorro-antd';
import { Router } from '@angular/router';
import { fadeIn } from '../../animation/fade-in';
import { PermissionService } from '../../shared/service/permission.service';
import { TranslateService } from '@ngx-translate/core';

@Component({
  selector: 'app-factory-manage',
  templateUrl: './factory-manage.component.html',
  animations: [fadeIn],
  styles: []
})
export class FactoryManageComponent implements OnInit {

  req: any = {};
  data: any = [];
  isLoading = false;
  isVisible = false;
  isUpdate = false;
  factoryName = '';
  nzOptions: any = [];
  area: any;
  imgUrl = '';
  roles = [];
  fileList = [];
  imgLoading = false;
  constructor(private api: ApiService, private message: NzMessageService,
              private modalService: NzModalService, private ck: CheckService,
              private router: Router, public per: PermissionService,
              private translate: TranslateService) { }

  ngOnInit() {
    this.imgUrl = this.api.url + '/img/photoUpload?imageType=factory';
    this.init();
  }

  init() {
    this.getData();
    this.getAreas();
    this.getRoles();
  }

  getAreas() {
    this.isLoading = true;
    this.api.area.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.initTree(data);
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
    }]);
  }

  getData() {
    this.isLoading = true;
    this.api.factory.getAllForFactoryArea(['', this.next]);
  }

  next = (data) => {
    if (data.constructor === Array) {
      this.data = data;
    } else if (data.code === 1) {
      this.message.success(data.message || this.translate.instant('operateSuccess'));
      this.isVisible = false;
      this.init();
    } else if (data.code === 0) {
      this.message.error(data.message || this.translate.instant('operateFail'));
    } else {
      this.message.error(data.message || this.translate.instant('wrongToGetData'));
    }
    this.isLoading = false;
  }

  add() {
    this.isUpdate = false;
    this.req = {};
    this.area = [];
    this.isVisible = true;
  }

  edit(item) {
    this.isUpdate = true;
    this.req = {...item};
    this.fileList = [{
      name: item.img,
      url: this.api.url + '/assets/static/monitoringPoint/' + item,
      status: 'done'
    }];
    this.isVisible = true;
    this.area = [item.province, item.city, item.area];
  }

  cancel() {
    this.isVisible = false;
  }

  save() {
    this.isLoading = true;
    const req = {...this.req};
    const check = {
      field:  this.isUpdate ? ['factoryName', 'city', 'area', 'addressDetail'] : ['factoryName', 'city', 'area', 'addressDetail', 'roleNo'],
      tel: ['phone']
    };
    if (!this.ck.formCheck(req, check)) {
      this.isLoading = false;
      return;
    }
    if (this.isUpdate) {
      this.api.factory.updateFactoryArea([req, this.next]);
    } else {
      this.api.factory.addFactory([req, this.next]);
    }
  }

  getRoles() {
    this.isLoading = true;
    this.api.role.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.roles = data;
      } else {
        this.message.error( data.message || this.translate.instant('wrongToGetData'));
      }
    }]);
  }

  deleteConfirm(one) {
    this.modalService.confirm({
      nzTitle  : '<i></i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteThisRecord') + '</b>',
      nzOnOk   : () => this.delete(one)
    });
  }

  delete(one) {
    this.isLoading = true;
    const req = {factoryNo: one.factoryNo};
    this.api.factory.deleteFactory([req, this.next]);
  }

  query() {
    this.isLoading = true;
    const req = {factoryName: this.factoryName};
    this.api.factory.getFactoryAreaByFactoryNameForLike([req, this.next]);
  }

  onSearch() {
    this.query();
  }

  onGetAll() {
    this.getData();
    this.factoryName = '';
  }

  onAreaChanges(e) {
    if (e.length === 3) {
      this.req.city = e[1];
      this.req.area = e[2];
    } else {
      this.req.city = '';
      this.req.area = '';
    }
  }

  initTree(data) {
    const obj = [];
    if (data.length > 0) {
      data.map((first: any, index) => {
        if (first.cityVoList && first.cityVoList.length > 0) {
          first.cityVoList.map((second: any, index_2) => {
            if (second.areaVos && second.areaVos.length > 0) {
              second.areaVos.map((third, index_3) => {
                if (obj.length < 1 || obj[obj.length - 1].label !== first.province) {
                  obj.push({label: first.province, value: first.province, children: []});
                  obj[obj.length - 1].children.push({label: second.city, value: second.city, children: []});
                } else if (obj[obj.length - 1].children[obj[obj.length - 1].children.length - 1].label !== second.city) {
                  obj[obj.length - 1].children.push({label: second.city, value: second.city, children: []});
                }
                obj[obj.length - 1].children[obj[obj.length - 1].children.length - 1].children.push({
                  label: third.area,
                  value: third.area,
                  isLeaf: true
                });
                if (index === data.length - 1 && index_2 === first.cityVoList.length - 1 && index_3 === second.areaVos.length - 1) {
                  this.nzOptions = obj;
                }
              });
            } else {
              if (index === data.length - 1 && index_2 === first.cityVoList.length - 1) {
                this.nzOptions = obj;
              }
            }
          });
        } else {
          if (index === data.length - 1) {
            this.nzOptions = obj;
          }
        }
      });
    }
  }

  imgChange(e) {
    if (e.type === 'success') {
      this.imgLoading = false;
      if (e.file.response.code === 1) {
        this.fileList = [e.file];
        this.req.img = e.file.response.message;
        this.message.success(this.translate.instant('picUploadSuccess'));
      } else {
        this.fileList = [];
        this.message.error(e.file.response.message || this.translate.instant('picUploadFailed'));
      }
    } else if (e.type === 'start') {
      this.imgLoading = true;
    } else if (e.type === 'progress') {
    } else {
      this.message.error(this.translate.instant('picUploadFailed'));
    }
  }
}
