import { Component, OnInit } from '@angular/core';
import { fadeIn } from '../../animation/fade-in';
import { ActivatedRoute } from '@angular/router';
import { ApiService } from '../../shared/service/api.service';
import { NzMessageService } from 'ng-zorro-antd';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-factory-paint',
  templateUrl: './factory-paint.component.html',
  animations: [fadeIn],
  styles: [`
    .forDragToPosition {
      position: relative;
    }
  `]
})
export class FactoryPaintComponent implements OnInit {

  imgUrl = '';
  url = '';
  setData = [];
  unsetData = [];
  req: any = {};
  isLoading = false;
  defaultUrl = '../../../assets/images/Layout.png';
  xMax = 0; yMax = 0;
  constructor(private activatedRoute: ActivatedRoute, private api: ApiService,
              private message: NzMessageService, private translate: TranslateService) {
  }

  ngOnInit() {
    this.activatedRoute.queryParams.subscribe((params) => {
      if (params.img) {
        this.imgUrl = this.api.imgUrl + '/assets/static/factory/' + params.img;
        this.url = this.api.imgUrl + '/assets/static/factory/' + params.img;
      }
      const img = new Image();
      img.src = this.url;
      img.onload = () => {
        this.xMax = img.width;
        this.yMax = img.height;
      };
      if (params.factoryNo) {
        this.getAllPoints(params.factoryNo);
      }
    });
    document.getElementById('bgImg').onselectstart = document.getElementById('bgImg').ondrag = function() {
      return false;
    };
  }

  imgOnError() {
    this.url = this.defaultUrl;
    const img = new Image();
    img.src = this.url;
    img.onload = () => {
      this.xMax = img.width;
      this.yMax = img.height;
    };
  }

  getAllPoints(factoryNo) {
    this.isLoading = true;
    const req = {factoryNo: factoryNo};
    this.api.monitoringPoint.getByFactoryAreaNo([req, (data) => {
      if (data.constructor === Array) {
        data.map((item, index) => {
          if (item.xaxis && !isNaN(parseInt(item.xaxis, 10))) {
            item.x = parseInt(item.xaxis, 10);
          } else {
            item.x = 0;
          }
          if (item.yaxis && !isNaN(parseInt(item.yaxis, 10))) {
            item.y = parseInt(item.yaxis, 10);
          } else {
            item.y = 0;
          }
          if (index === data.length - 1) {
            this.setData = data.filter((one) => one.x && one.y);
            this.unsetData = data.filter((one) => !(one.x && one.y));
          }
        });
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  add() {
    this.isLoading = true;
    if (!this.req.monitoringPointNo) {
      this.message.error(this.translate.instant('pleaseChooseMonitoringPoint'));
      this.isLoading = false;
      return;
    }
    const one  = this.unsetData.filter((item) => item.monitoringPointNo === this.req.monitoringPointNo)[0];
    const req = {...one};
    req.xaxis = 1;
    req.yaxis = 1;
    req.alarmNo = this.req.alarmNo;
    this.api.monitoringPoint.updateMonitoringPoint([req, (data) => {
      if (data.code === 1) {
        this.ngOnInit();
        this.req = {};
      } else {
        this.message.error(data.message || this.translate.instant('operateFail'));
      }
      this.isLoading = false;
    }]);
  }
}
