import { Component, OnInit, ViewChild } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { CheckService } from '../../shared/service/check.service';
import { NzMessageService, NzModalService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import { TransferComponent } from '../../shared/transfer/transfer.component';
import { PermissionService } from '../../shared/service/permission.service';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-gateway-manage',
  templateUrl: './gateway-manage.component.html',
  animations: [fadeIn],
  styles: [`.multi {
      position: absolute;
      height: 32px;
      line-height: 20px;
      padding: 4px 6px;
      border-radius: 18px;
      font-weight: 600;
    }
    
    .multiAdd {
      left: 44px;
      top: -3px;
      border: 0.18em solid #52c41a;
      color: #52c41a;
    }
    .multiDel {
      left: 138px;
      top: -3px;
      border: 0.18em solid #ff2c32;
      color: #ff2c32;
    }
  `]
})
export class GatewayManageComponent implements OnInit {

  req: any = {};
  req2: any = {};
  data: Array<object> = [];
  isLoading = false;
  query: any = { sn: '', gatewayName: '', factoryNo: ''};
  factorys: Array<object> = [];
  isVisible = false;
  isVisible2 = false;
  isUpdate = false;
  models: Array<object> = [];
  isVisible3 = false;
  selectDevice = '';
  collectors = [];
  loading: Array<boolean> = [false, false, false, false, false, false, false, false, false, false];
  types = [{label: 'WTH407', value: 'WTH407'}, {label: 'WTG301', value: 'WTG301'}];
  @ViewChild('transfer1')
  transfer: TransferComponent;

  constructor(private api: ApiService, private message: NzMessageService, private translate: TranslateService,
              private modalService: NzModalService, private ck: CheckService, public per: PermissionService) {
  }

  ngOnInit() {
    this.init();
  }

  init() {
    this.getData();
    this.getModels();
    this.getFactorys();
    this.getCollectors();
  }

  getCollectors() {
    this.isLoading = true;
    const req = {type: ''};
    this.api.sensor.getByFreeForType([req, (data) => {
      if (data.constructor === Array) {
        this.collectors = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getData() {
    this.isLoading = true;
    this.api.gateway.getAll(['', this.next]);
  }

  getFactorys() {
    this.isLoading = true;
    this.api.factory.getAllForFactoryArea(['', (data) => {
      if (data.constructor === Array) {
        this.factorys = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getModels() {
    this.isLoading = true;
    this.api.model.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.models = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  onSearch() {
    this.isLoading = true;
    const req = {
      factoryNo: this.query.factoryNo,
      gatewayName: this.query.gatewayName,
      sn: this.query.sn
    };
    this.api.gateway.getAllForLike([req, this.next]);
  }

  next = (data) => {
    if (data && data.constructor === Array) {
      this.data = data;
    } else if ( data.code === 1) {
      this.message.success(data.message || this.translate.instant('operateSuccess'));
      this.isVisible = false;
      this.isVisible2 = false;
      this.isVisible3 = false;
      this.init();
    } else if (data.code === 0) {
      this.message.error(data.message || this.translate.instant('operateFail'));
    } else {
      this.message.error(data.message || this.translate.instant('wrongToGetData'));
    }
    this.isLoading = false;
    this.loading = [false, false, false, false, false, false, false, false, false, false];
  }

  onGetAll() {
    this.query = {};
    this.getData();
  }

  add() {
    this.isUpdate = false;
    this.req = {};
    this.isVisible = true;
  }

  edit(item) {
    this.isUpdate = true;
    this.req = {...item};
    this.isVisible = true;
  }

  deleteConfirm(one) {
    this.modalService.confirm({
      nzTitle  : '<i></i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteThisRecord') + '</b>',
      nzOnOk   : () => this.delete(one)
    });
  }

  delete(one) {
    this.isLoading = true;
    const req = {deviceNo: one.deviceNo};
    this.api.gateway.deleteGateway([req, this.next]);
  }

  save() {
    this.isLoading = true;
    const req = {...this.req};
    const check = {
      field: ['type', 'gatewayName', 'sn']
    };
    if (!this.ck.formCheck(req, check)) {
      this.isLoading = false;
      return;
    }
    if (this.isUpdate) {
      this.api.gateway.updateGateway([req, this.next]);
    } else {
      this.api.gateway.addGateway([req, this.next]);
    }
  }

  cancel() {
    this.isVisible = false;
  }

  clickSwitch(one, i) {
    this.loading[i] = true;
    const req = {
      deviceNo: one.deviceNo,
      gatewayState: one.gatewayState ? 0 : 1
    };
    this.api.gateway.disonnectGateway([req, (data) => {
      if (data.code === 1) {
        this.message.success(data.message || this.translate.instant('operateSuccess'));
        this.loading[i] = false;
        one.gatewayState = !one.gatewayState;
      } else {
        this.message.error(data.message || this.translate.instant('operateFail'));
      }
    }]);
  }

  divide(one) {
    this.isVisible2 = true;
    this.req2.deviceNo = one.deviceNo;
  }

  bind(one) {
    this.selectDevice = one.deviceNo;
    this.isVisible3 = true;
  }

  cancel2() {
    this.isVisible2 = false;
  }

  save2() {
    this.isLoading = true;
    this.api.gateway.allocationGateway([this.req2, this.next]);
  }

  cancel3() {
    this.isVisible3 = false;
  }

  save3() {
    this.isLoading = true;
    const list = this.transfer.right;
    const sensorDeviceNos = [];
    if (list.length <= 0) {
      this.message.error(this.translate.instant('pleaseChooseSensor'));
      this.isLoading = false;
      return;
    } else {
      list.map((item, index) => {
        sensorDeviceNos.push(item.sensorDeviceNo);
        if (index === list.length - 1) {
          const req = {
            gatewayDeviceNo: this.selectDevice,
            sensorDeviceNos: sensorDeviceNos
          };
          this.api.sensor.bindSensor([req, this.next]);
        }
      });
    }
  }

  multiAdd() {}

  multiDel() {}
}
