import { Component, OnInit } from '@angular/core';
import { fadeIn } from '../../animation/fade-in';
import { ApiService } from '../../shared/service/api.service';
import { NzMessageService } from 'ng-zorro-antd';
import { TranslateService } from '@ngx-translate/core';
import { Router } from '@angular/router';

@Component({
  selector: 'app-home',
  templateUrl: './home.component.html',
  styleUrls: ['./home.component.scss'],
  animations: [fadeIn]
})
export class HomeComponent implements OnInit {
  option1 = {
    tooltip: {
      trigger: 'item',
      formatter: '{b}: {c} ({d}%)'
    },
    series: [
      {
        name: '',
        type: 'pie',
        radius: [0, '50%'],
        label: {
          normal: {
            position: 'inner'
          }
        },
        labelLine: {
          normal: {
            show: false
          }
        },
        data: []
      },
      {
        name: '',
        type: 'pie',
        radius: ['65%', '90%'],
        label: {
          normal: {
            position: 'inner'
          }
        },
        labelLine: {
          normal: {
            show: false
          }
        },
        data: []
      }
    ]
  };
  option3 = {
    tooltip: {
      trigger: 'axis'
    },
    legend: {
      data: [],
      top: '2px'
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      top: '30px',
      containLabel: true
    },
    xAxis: {
      type: 'category',
      data: []
    },
    yAxis: {
      type: 'value'
    },
    series: [
      {
        name: '',
        type: 'line',
        symbol: 'circle',
        symbolSize: 10,
        lineStyle: {
          color: '#722ed1'
        },
        itemStyle: {
          color: '#722ed1'
        },
        data: []
      }, {
        name: '',
        type: 'line',
        symbol: 'circle',
        symbolSize: 10,
        lineStyle: {
          color: '#1890ff'
        },
        itemStyle: {
          color: '#1890ff'
        },
        data: []
      }, {
        name: '',
        type: 'line',
        lineStyle: {
          color: '#f5222d'
        },
        itemStyle: {
          color: '#f5222d'
        },
        symbol: 'circle',
        symbolSize: 10,
        data: []
      }
    ]
  };
  option4: any = {};
  items = [];
  data: any = {};
  isLoading = false;
  points = [];
  img = '';
  constructor(private api: ApiService, private message: NzMessageService,
              private translate: TranslateService, private router: Router) { }

  ngOnInit() {
    this.init();
  }

  init() {
    this.getData();
  }

  imgOnError() {
    this.img = '../../../assets/images/Layout.png';
  }

  getData() {
    this.api.homePage.homePage(['', (data) => {
      if (data && data.resultFactoryVo) {
        this.data = data;
        this.img = this.api.imgUrl + '/assets/static/factory/' + data.resultFactoryVo.img;
        const obj = data.homePageMonitoringPointVos;
        if ( obj && obj.constructor === Array && obj.length > 1) {
          obj.map((item, index) => {
            item.xaxis = item.resultMonitoringPointForHomePageVo.xaxis;
            item.yaxis = item.resultMonitoringPointForHomePageVo.yaxis;
            item.monitoringPointName = item.resultMonitoringPointForHomePageVo.monitoringPointName;
            item.monitoringPointNo = item.resultMonitoringPointForHomePageVo.monitoringPointNo;
            if (item.xaxis && !isNaN(parseInt(item.xaxis, 10))) {
              item.x = parseInt(item.xaxis, 10);
            } else {
              item.x = 0;
            }
            if (item.yaxis && !isNaN(parseInt(item.yaxis, 10))) {
              item.y = parseInt(item.yaxis, 10);
            } else {
              item.y = 0;
            }
            if (index === obj.length - 1) {
              this.points = obj.filter((one) => one.x && one.y);
            }
          });
        }
        const option = JSON.parse(JSON.stringify(this.option1));
        option.series[0].name = '';
        const xdknormal = {value: data.xdknormal, name: this.translate.instant('normal'), itemStyle: {color: '#1890ff'}};
        const xdkalarm = {value: data.xdkalarm, name: this.translate.instant('alarm'), itemStyle: {color: '#f5222d'}};
        option.series[0].data = data.xdknormal || data.xdkalarm ? data.xdknormal && !data.xdkalarm ? [xdknormal] :
          !data.xdknormal && data.xdkalarm ? [xdkalarm] : [xdknormal, xdkalarm] : [{value: 0, name: '-', itemStyle: {color: '#bfbfbf'}}];
        const xdkonline = {value: data.xdkonline, name: this.translate.instant('online'), itemStyle: {color: '#52c41a'}};
        const xdkoffLine = {value: data.xdkoffLine, name: this.translate.instant('offline'), itemStyle: {color: '#bfbfbf'}};
        option.series[1].name = '';
        option.series[1].data = data.xdkonline || data.xdkoffLine ? data.xdkonline && !data.xdkoffLine ? [xdkonline] :
          !data.xdkonline && data.xdkoffLine ? [xdkoffLine] : [xdkonline, xdkoffLine] : [{value: 0, name: '-', itemStyle: {color: '#bfbfbf'}}];
        this.option4 = JSON.parse(JSON.stringify(option));
        const cissnormal = {value: data.cissnormal, name: this.translate.instant('normal'), itemStyle: {color: '#1890ff'}};
        const cissalarm = {value: data.cissalarm, name: this.translate.instant('alarm'), itemStyle: {color: '#f5222d'}};
        option.series[0].data = data.cissnormal || data.cissalarm ? data.cissnormal && !data.cissalarm ? [cissnormal] :
            !data.cissnormal && data.cissalarm ? [cissalarm] : [cissnormal, cissalarm] : [{value: 0, name: '-', itemStyle: {color: '#bfbfbf'}}];
        const cissonline = {value: data.cissonline, name: this.translate.instant('online'), itemStyle: {color: '#52c41a'}};
        const cissoffLine = {value: data.cissoffLine, name: this.translate.instant('offline'), itemStyle: {color: '#bfbfbf'}};
        option.series[1].data = data.cissonline || data.cissoffLine ? data.cissonline && !data.cissoffLine ? [cissonline] :
          !data.cissonline && data.cissoffLine ? [cissoffLine] : [cissonline, cissoffLine] : [{value: 0, name: '-', itemStyle: {color: '#bfbfbf'}}];
        this.option1 = {...option};
        if (data.resultAlarmCountForWeekVos && data.resultAlarmCountForWeekVos.constructor === Array && data.resultAlarmCountForWeekVos.length > 0) {
          const alarmX = [];
          const alarmData = [];
          const dispose = [];
          const unDispose = [];
          data.resultAlarmCountForWeekVos.map((item, index) => {
            alarmX.push(item.dataTime);
            alarmData.push(item.alarmCount);
            dispose.push(item.alarmDisposeCount);
            unDispose.push(item.alarmUnDisposeCount);
            if (index === data.resultAlarmCountForWeekVos.length - 1) {
              const option3 = {...this.option3};
              option3.legend.data = [this.translate.instant('alarm'), this.translate.instant('disposed'), this.translate.instant('unDispose')];
              option3.xAxis.data = alarmX;
              option3.series[0].data = alarmData;
              option3.series[1].data = dispose;
              option3.series[2].data = unDispose;
              option3.series[0].name = this.translate.instant('alarm');
              option3.series[1].name = this.translate.instant('disposed');
              option3.series[2].name = this.translate.instant('unDispose');
              this.option3 = option3;
            }
          });
        }
        this.items = data.resultAlarmLogVos ? data.resultAlarmLogVos : [];
      } else {
        this.message.error(data.message);
      }
    }]);
  }

  linkToDetail(one) {
    const type = one.resultMonitoringPointForHomePageVo.monitoringPointType;
    if (type === '机房') {
      this.router.navigate(['/app/pointAnalyse/machineRoom/machineRoomDetail'], { queryParams: {monitoringPointNo: one.resultMonitoringPointForHomePageVo.monitoringPointNo} });
    } else if (type === '切削机') {
      // const req = {monitoringPointNo: one.resultMonitoringPointForHomePageVo.monitoringPointNo, sensorSN: one.resultMonitoringPointForHomePageVo.sensorSN};
      // this.router.navigate(['/app/pointAnalyse/cuttingMachine/cuttingMachineDetail'], {queryParams: req});
      this.router.navigate(['/app/pointAnalyse/cuttingMachine/cuttingMachineDetail'], { queryParams: {monitoringPointNo: one.resultMonitoringPointForHomePageVo.monitoringPointNo, sensorSN: one.resultMonitoringPointForHomePageVo.sensorSN} });
    }
  }
}
