import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { ApiService } from '../../shared/service/api.service';
import { NzMessageService } from 'ng-zorro-antd';
import { PermissionService } from '../../shared/service/permission.service';
import { fadeIn } from '../../animation/fade-in';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-machine-room-detail',
  templateUrl: './machine-room-detail.component.html',
  styles: [`
    .noData {
      border-top: 1px solid #ccc;
      padding: 10px 0 0 0;
    }
  `],
  animations: [fadeIn]
})
export class MachineRoomDetailComponent implements OnInit {

  device: any = {};
  optionArray = [];
  isLoading = false;
  name = '';
  option = {
    title: {
      text: ''
    },
    tooltip: {
      trigger: 'axis',
    },
    legend: {
      data: [],
      top: '6%'
    },
    dataZoom: [
      {
        type: 'slider',
        show: true,
        start: 0,
        bottom: '15px',
        end: 100
      },
      {
        type: 'inside',
        start: 0,
        end: 100
      }
    ],
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      containLabel: true
    },
    xAxis: {
      type: 'time',
      boundaryGap: false,
      axisLabel: {}
    },
    yAxis: {
      type: 'value'
    },
    series: []
  };
  timeData = [{label: 'lastDay', value: 1}, {label: 'lastWeek', value: 7}, {label: 'lastHalfMonth', value: 15}, {
    label: 'lastMonth',
    value: 30
  }];
  alarmData = [{alarmTime: 1545574442000}];
  monitoringPointNo = '';
  data: any;
  alarmChart = {};
  isVisible = false;
  isVisible2 = false;
  req: any = {};

  constructor(private acRouter: ActivatedRoute, public per: PermissionService,
              private api: ApiService, private message: NzMessageService, private translate: TranslateService) {
  }

  ngOnInit() {
    this.acRouter.queryParams.subscribe((params) => {
      if (params.monitoringPointNo) {
        this.monitoringPointNo = params.monitoringPointNo;
        this.device.selectTime = 1;
        this.device.selectTime2 = 1;
        this.getData();
        this.getAlarmData();
      }
    });
  }

  getData() {
    this.isLoading = true;
    const req = {
      endTime: new Date().getTime(),
      monitoringPointNo: this.monitoringPointNo,
      startTime: new Date().getTime() - 24 * 60 * 60 * 1000 * Number(this.device.selectTime),
      duration: Number(this.device.selectTime),
      offset: 0 - new Date().getTimezoneOffset() / 60
    };
    this.api.analysis.getMachineRoomDetail([req, (data) => {
      if (data && data.resultMonitoringPointVo) {
        this.data = data;
        if (data && data.resultMachineRoomForSensorVos && data.resultMachineRoomForSensorVos.length > 0) {
          const tempObj = [];
          const humidObj = [];
          data.resultMachineRoomForSensorVos.map((item, index) => {
            if (item.resultDataTempVos && item.resultDataTempVos.length > 0) {
              tempObj.push({data: item.resultDataTempVos, detail: item.resultSensorVo});
            }
            if (item.resultDataHumidVos && item.resultDataHumidVos.length > 0) {
              humidObj.push({data: item.resultDataHumidVos, detail: item.resultSensorVo});
            }
            if (index === data.resultMachineRoomForSensorVos.length - 1) {
              this.createTempChart(tempObj);
              this.createHumidChart(humidObj);
            }
          });
          setTimeout(() => {
            this.isLoading = false;
          }, 2000);
        } else {
          this.isLoading = false;
        }
      } else {
        this.isLoading = false;
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
    }]);
  }

  createTempChart(data) {
    const option: any = JSON.parse(JSON.stringify(this.option));
    option.tooltip.formatter = (value) => {
      let str =  this.translate.instant('time') + ':' + this.transTime(value[0].data[0]);
      for (let i = 0; i < value.length; i++) {
        str = str + '<br/>' + value[i].seriesName + ' : ' + Number(value[i].data[1]).toFixed(1) + '℃';
        if (i === value.length - 1) {
          return str;
        }
      }
    };
    option.xAxis.axisLabel.formatter = (value) => {
      return this.transTime(value, 1);
    };
    data.map((item, index) => {
      const dataArr = [];
      const series: any = {};
      series.name = item.detail.sensorSN + this.translate.instant('temp') + this.translate.instant('data');
      series.type = 'line';
      series.symbol = 'none';
      option.legend.data.push(item.detail.sensorSN + this.translate.instant('temp') + this.translate.instant('data'));
      if (item.data.length > 0) {
        item.data.map((one, num) => {
          dataArr.push([one.time - 0, one.value]);
          if (num === item.data.length - 1) {
            series.data = dataArr;
            option.series.push(series);
          }
          if (index === data.length - 1 && num === item.data.length - 1) {
            option.title.left = 'center';
            option.title.text = this.translate.instant('temp') + this.translate.instant('data');
            this.optionArray.push(option);
          }
        });
      }
    });
  }

  createHumidChart(data) {
    const option: any = JSON.parse(JSON.stringify(this.option));
    option.tooltip.formatter = (value) => {
      let str = this.translate.instant('time') + ':' + this.transTime(value[0].data[0]);
      for (let i = 0; i < value.length; i++) {
        str = str + '<br/>' + value[i].seriesName + ' : ' + Number(value[i].data[1]).toFixed(2) + '%rH';
        if (i === value.length - 1) {
          return str;
        }
      }
    };
    option.xAxis.axisLabel.formatter = (value) => {
      return this.transTime(value, 1);
    };
    data.map((item, index) => {
      const dataArr = [];
      const series: any = {};
      series.name = item.detail.sensorSN + this.translate.instant('humid') + this.translate.instant('data');
      series.type = 'line';
      series.symbol = 'none';
      option.legend.data.push(item.detail.sensorSN + this.translate.instant('humid') + this.translate.instant('data'));
      if (item.data.length > 0) {
        item.data.map((one, num) => {
          dataArr.push([one.time - 0, one.value]);
          if (num === item.data.length - 1) {
            series.data = dataArr;
            option.series.push(series);
          }
          if (index === data.length - 1 && num === item.data.length - 1) {
            option.title.left = 'center';
            option.title.text = this.translate.instant('humid') + this.translate.instant('data');
            this.optionArray.push(option);
            this.isLoading = false;
          }
        });
      }
    });
  }

  private transTime(value, type?) {
    const date: any = new Date(value - 0);
    const texts = [date.getFullYear(), this.addZero(date.getMonth() + 1), this.addZero(date.getDate())];
    // const texts = [date.getFullYear(), date.getMonth() + 1, date.getDate()].join('/');
    const time = [this.addZero(date.getHours()), this.addZero(date.getMinutes()), this.addZero(date.getSeconds())];
    const ref = type ? texts.join('-') + '\n' + time.join(':') : texts.join('-') + ' ' + time.join(':');
    return ref;
  }

  private addZero(date) {
    if (date.toString().length === 1) {
      date = '0' + date.toString();
    }
    return date;
  }

  getAlarmData() {
    this.isLoading = true;
    const req = {
      endTime: new Date().getTime(),
      monitoringPointNo: this.monitoringPointNo,
      startTime: new Date().getTime() - 24 * 60 * 60 * 1000 * Number(this.device.selectTime2),
      offset: 0 - new Date().getTimezoneOffset() / 60
    };
    this.api.analysis.getMachineRoomAlarm([req, (data) => {
      if (data.constructor === Array) {
        this.alarmData = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  onSearch() {
    this.optionArray = [];
    this.getData();
  }

  onAlarmSearch() {
    this.getAlarmData();
  }

  detail(one) {
    this.isLoading = true;
    const req = {
      alarmNo: one.alarmLogNo,
      endTime: new Date(one.alarmTime - 0).getTime() + 150 * 1000,
      offset: 0 - new Date().getTimezoneOffset() / 60,
      startTime: new Date(one.alarmTime - 0).getTime() - 150 * 1000
    };
    this.api.analysis.getMachineRoomAlarmDetail([req, (data) => {
      if (data.constructor === Array) {
        this.paintAlarmChart(one.parameter, data);
        this.isVisible = true;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      setTimeout(() => {
        this.isLoading = false;
      }, 2000);
    }]);
  }

  paintAlarmChart(type, data) {
    const option: any = JSON.parse(JSON.stringify(this.option));
    option.tooltip.formatter = (value) => {
      return this.translate.instant('time') + ':' + this.transTime(value[0].data[0]) + '<br/>' + this.translate.instant(type) + ':' + value[0].data[1];
    };
    option.xAxis.axisLabel.formatter = (value) => {
      return this.transTime(value, 1);
    };
    const dataArr = [];
    const markPoint = {
      label: {
        show: true,
        formatter: '{c}'
      },
      data: []
    };
    const series: any = {};
    series.name = this.translate.instant(type) + this.translate.instant('data');
    option.title.left = 'center';
    option.title.text = this.translate.instant(type) + this.translate.instant('data');
    series.type = 'line';
    if (data.length > 0) {
      data.map((one, num) => {
        dataArr.push([one.time - 0, one.value]);
        if (one.checked) {
          markPoint.data.push({
            coord: [Number(one.time), Number(one.value)],
            name: one.value,
            value: Number(one.value)
          });
        }
        if (num === data.length - 1) {
          series.data = dataArr;
          series.markPoint = markPoint;
          option.series.push(series);
          this.alarmChart = option;
        }
      });
    } else {
      this.alarmChart = option;
    }
  }

  cancel() {
    this.isVisible = false;
  }

  handle(one) {
    this.req = {};
    this.req.alarmLogNo = one.alarmLogNo;
    this.req.faultHandle = JSON.parse(decodeURIComponent(window.sessionStorage.getItem(encodeURIComponent('_AMap_AMap.IndoorMapFunc')))).userName;
    this.isVisible2 = true;
  }

  cancel2() {
    this.isVisible2 = false;
  }

  confirm2() {
    this.isLoading = true;
    this.api.alarmLog.disposeAlarm([this.req, (data) => {
      if (data.code === 1) {
        this.isVisible2 = false;
        this.message.success(data.message || this.translate.instant('operateSuccess'));
        this.getAlarmData();
      } else {
        this.message.error(data.message || this.translate.instant('operateFail'));
      }
      this.isLoading = false;
    }]);
  }
}
