import { Component, OnInit } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { NzMessageService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import { PermissionService } from '../../shared/service/permission.service';
import { Router } from '@angular/router';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-machine-room',
  templateUrl: './machine-room.component.html',
  animations: [fadeIn]
})
export class MachineRoomComponent implements OnInit {

  req: any = {};
  data: any = [];
  isLoading = false;
  name = '';
  constructor(private api: ApiService, private message: NzMessageService,
              public per: PermissionService, private router: Router, private translate: TranslateService) { }

  ngOnInit() {
    this.init();
  }

  init() {
    this.getData();
  }

  getData() {
    this.isLoading = true;
    this.api.analysis.getMachineRoom(['', (data) => {
      if (data.constructor === Array) {
        this.data = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  query() {
    this.isLoading = true;
    const req = {monitoringPointName: this.name};
    this.api.analysis.getMachineRoomForLike([req, (data) => {
      if (data.constructor === Array) {
        this.data = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  onSearch() {
    this.query();
  }

  onGetAll() {
    this.getData();
    this.name = '';
  }

  detail(one) {
    const req = {monitoringPointNo: one.monitoringPointNo};
    this.router.navigate(['app/pointAnalyse/machineRoom/machineRoomDetail'], {queryParams: req});
  }
}
