import { Component, OnInit } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { NzMessageService, NzModalService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import { PermissionService } from '../../shared/service/permission.service';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-operate-set',
  templateUrl: './operate-set.component.html',
  animations: [fadeIn]
})
export class OperateSetComponent implements OnInit {

  req: any = {};
  data = [];
  isLoading = false;
  page = 1;
  rows = 10;
  total;
  constructor(private api: ApiService, private message: NzMessageService,
              private translate: TranslateService, public per: PermissionService) {
  }

  ngOnInit() {
    this.init();
  }

  init() {
    this.getData();
  }

  getData() {
    this.isLoading = true;
    this.api.operationLog.getAll(this.page, this.rows, ['', this.next]);
  }

  next = (data) => {
    if (data && data.rows && data.rows.constructor === Array) {
      this.data = data.rows;
      this.total = data.total;
    } else if (data.code === 1) {
      this.message.success(data.message || this.translate.instant('operateSuccess'));
      this.init();
    } else if (data.code === 0) {
      this.message.error(data.message || this.translate.instant('operateFail'));
    } else {
      this.message.error(data.message || this.translate.instant('wrongToGetData'));
    }
    this.isLoading = false;
  }

  query() {
    this.isLoading = true;
    const req = {
      operationName: this.req.operationName || '',
      startTime: this.req.startTime || '',
      stopTime: this.req.stopTime || '',
      userName: this.req.userName || ''
    };
    this.api.operationLog.getByTerm(this.page, this.rows, [req, this.next]);
  }

  onSearch() {
    this.page = 1;
    this.query();
  }

  onGetAll() {
    this.page = 1;
    this.getData();
  }

  searchData() {
    if (this.req.operationName || this.req.startTime || this.req.stopTime || this.req.userName) {
      this.query();
    } else {
      this.getData();
    }
  }

  output() {
    this.isLoading = true;
    const req = {
      factoryNo: this.req.factoryNo || '',
      operationName: this.req.operationName || '',
      startTime: this.req.startTime || '',
      stopTime: this.req.stopTime || '',
      userName: this.req.userName || ''
    };
    this.api.operationLog.downloadExcel([req, (data) => {
      if (data.code === 1) {
        window.location.href = data.message;
      } else {
        this.message.error(data.message || this.translate.instant('operateFail'));
      }
      this.isLoading = false;
    }]);
  }
}
