import { Component, OnInit } from '@angular/core';
import { fadeIn } from '../../animation/fade-in';
import { ApiService } from '../../shared/service/api.service';
import { NzMessageService, NzModalService } from 'ng-zorro-antd';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-person-set',
  templateUrl: './person-set.component.html',
  styleUrls: ['./person-set.component.scss'],
  animations: [fadeIn]
})
export class PersonSetComponent implements OnInit {

  constructor(private api: ApiService, private message: NzMessageService, private translate: TranslateService) {
  }

  public userForChange: any = {};
  public isUpdate = false;
  public updatePwd: any = {};
  public isVisible = false;
  public userImgUrl = '';
  public fileList = [];
  public previewVisible = false;
  public previewImage = '';
  public usr: any = {};
  isLoading = false;
  originImg = '';
  changedImg = '';
  isShowLoading = true;

  ngOnInit() {
    this.getUserInfo();
  }

  private getUserInfo() {
    this.isLoading = true;
    this.api.user.getSelfInfo(['', (data: any) => {
      if (data.constructor === Object) {
        this.userForChange = data;
        this.changedImg = data.img;
        this.usr = data;
        this.originImg = this.usr.img || '../../../assets/images/none.png';
        this.userImgUrl = this.api.url + '/img/photoUpload?imageType=head';
        this.fileList = [{
          status: 'done',
          url: this.usr.img || '../../../assets/images/none.png'
        }];
      } else {
        this.message.error(data.message);
      }
      this.isLoading = false;
      this.isShowLoading = false;
    }]);
  }

  fileChange(event) {
    if (event.type === 'success') {
      if (event.file.response.code === 1) {
        this.fileList = [{
          status: 'done',
          url: this.api.imgUrl + '/assets/static/head/' + event.file.response.message
        }];
        this.changedImg = this.api.imgUrl + '/assets/static/head/' + event.file.response.message;
        this.userForChange.img = this.api.imgUrl + '/assets/static/head/' + event.file.response.message;
        this.message.success(this.translate.instant('picUploadSuccess'));
      } else {
        this.message.error(event.file.response.message);
      }
    } else if (event.type === 'removed') {
      this.changedImg = '';
      this.userForChange.img = '';
    }
  }

  saveImg() {
    const req = {...this.usr};
    req.img = this.changedImg;
    this.isLoading = true;
    this.api.user.updateUser([req, (data: any) => {
      if (data.code === 1) {
        this.getUserInfo();
        this.isUpdate = false;
        this.message.success(data.message);
      } else {
        this.message.error(data.message);
      }
      this.isLoading = false;
    }]);
  }

  changePsword() {
    this.updatePwd = {};
    this.isVisible = true;
  }

  save() {
    this.isLoading = true;
    this.api.user.updateUser([this.userForChange, (data: any) => {
      if (data.code === 1) {
        this.getUserInfo();
        this.isUpdate = false;
        this.message.success(data.message);
      } else {
        this.message.error(data.message);
      }
      this.isLoading = false;
    }]);
  }

  cancel() {
    this.isVisible = false;
  }

  edit() {
    this.isUpdate = true;
  }

  savePsword() {
    this.isLoading = true;
    if (this.updatePwd.newPwd1 !== this.updatePwd.newPwd1) {
      this.message.error(this.translate.instant('differentPassword'));
      return;
    }
    this.api.user.updateSelfPassword([{
      password: this.updatePwd.newPwd1,
      oldPassword: this.updatePwd.oldPwd
    }, (data: any) => {
      if (data.code === 1) {
        this.message.success(data.message);
        this.isVisible = false;
        this.isUpdate = false;
        this.getUserInfo();
      } else {
        this.message.error(data.message);
      }
      this.isLoading = false;
    }]);
  }

  handlePreview = () => {
    this.previewImage = this.userForChange.img || '';
    this.previewVisible = true;
  }

  changeImg() {
    this.previewImage = '../../../assets/images/none.png';
  }
}
