import { Component, OnInit } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { CheckService } from '../../shared/service/check.service';
import { NzMessageService, NzModalService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import { Router } from '@angular/router';
import { PermissionService } from '../../shared/service/permission.service';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-point-manage',
  templateUrl: './point-manage.component.html',
  animations: [fadeIn]
})
export class PointManageComponent implements OnInit {

  req: any = {};
  req2: any = {};
  data: any = [];
  isBind = true;
  isLoading = false;
  isVisible = false;
  isVisible2 = false;
  isUpdate = false;
  monitoringPointName = '';
  areas = [];
  sensors = [];
  pointSensors = [];
  alarms = [];
  imgUrl = '';
  fileList = [];
  imgLoading = false;
  pointTypes = [];

  constructor(private api: ApiService, private message: NzMessageService,
              private modalService: NzModalService, private ck: CheckService,
              public per: PermissionService, private translate: TranslateService) {
  }

  ngOnInit() {
    this.imgUrl = this.api.url + '/img/photoUpload?imageType=monitoringPoint';
    this.init();
  }

  init() {
    this.getData();
    this.getAreas();
    this.getSensors();
    this.getAlarms();
    this.getPointTypes();
  }

  getAlarms() {
    this.isLoading = true;
    this.api.alarm.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.alarms = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getSensors() {
    this.isLoading = true;
    this.api.sensor.getByFreeAndBindGateway(['', (data) => {
      if (data.constructor === Array) {
        this.sensors = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
    }]);
  }

  getAreas() {
    this.isLoading = true;
    this.api.factory.getAllForFactoryLine(['', (data) => {
      if (data.constructor === Array) {
        this.areas = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getData() {
    this.isLoading = true;
    this.api.monitoringPoint.getAll(['', this.next]);
  }

  next = (data) => {
    if (data.constructor === Array) {
      this.data = data.filter((item) => item.monitoringPointName.indexOf(this.monitoringPointName) > -1);
    } else if (data.code === 1) {
      this.message.success(data.message || this.translate.instant('operateSuccess'));
      this.isVisible = false;
      this.isVisible2 = false;
      this.init();
    } else if (data.code === 0) {
      this.message.error(data.message || this.translate.instant('operateFail'));
    } else {
      this.message.error(data.message || this.translate.instant('wrongToGetData'));
    }
    this.isLoading = false;
  }

  add() {
    this.isUpdate = false;
    this.req = {};
    this.fileList = [];
    this.isVisible = true;
  }

  edit(item) {
    this.isUpdate = true;
    this.req = {...item};
    this.fileList = [{
      name: item.img,
      url: this.api.url + '/assets/static/monitoringPoint/' + item,
      status: 'done'
    }];
    this.isVisible = true;
  }

  cancel() {
    this.isVisible = false;
  }

  save() {
    this.isLoading = true;
    const req = {...this.req};
    req.xaxis = 0;
    req.yaxis = 0;
    const check = {
      field: ['monitoringPointType', 'monitoringPointName', 'factoryNo'],
      tel: ['phone']
    };
    if (!this.ck.formCheck(req, check)) {
      this.isLoading = false;
      return;
    }
    if (this.isUpdate) {
      this.api.monitoringPoint.updateMonitoringPoint([req, this.next]);
    } else {
      this.api.monitoringPoint.addMonitoringPoint([req, this.next]);
    }
  }

  deleteConfirm(one) {
    this.modalService.confirm({
      nzTitle: '<i></i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteThisRecord') + '</b>',
      nzOnOk: () => this.delete(one)
    });
  }

  delete(one) {
    this.isLoading = true;
    const req = {monitoringPointNo: one.monitoringPointNo};
    this.api.monitoringPoint.deleteMonitoringPoint([req, this.next]);
  }

  query() {
    this.isLoading = true;
    this.api.monitoringPoint.getAll(['', this.next]);
  }

  onSearch() {
    this.query();
  }

  onGetAll() {
    this.monitoringPointName = '';
    this.getData();
  }

  bind(one) {
    this.isBind = true;
    this.req2 = {};
    this.req2.monitoringPointNo = one.monitoringPointNo;
    this.isVisible2 = true;
  }

  unbind(one) {
    this.isLoading = true;
    this.isBind = false;
    this.req2 = {};
    this.req2.monitoringPointNo = one.monitoringPointNo;
    const req = {
      monitorPointNo: one.monitoringPointNo
    };
    this.api.sensor.getByMonitoringPoint([req, (data) => {
      if (data.constructor === Array) {
        this.pointSensors = data;
        this.isVisible2 = true;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  cancel2() {
    this.isVisible2 = false;
  }

  save2() {
    this.isLoading = true;
    if (this.isBind) {
      const req = {
        monitoringPointNo: this.req2.monitoringPointNo,
        sensorDeviceNos: [this.req2.deviceNo],
        alarmNos: [this.req2.alarmNo],
        xaxis: [0],
        yaxis: [0]
      };
      if (this.req2.deviceNo && this.req2.deviceNo.length > 0 && this.req2.alarmNo && this.req2.alarmNo.length > 0) {
        this.api.sensor.bindSensorAndMonitoringPoint([req, this.next]);
      } else {
        this.message.error(this.translate.instant('pleaseFillRequired'));
      }
    } else {
      const req = {
        monitoringPointNo: this.req2.monitoringPointNo,
        sensorDeviceNos: this.req2.deviceNo
      };
      if (this.req2.deviceNo && this.req2.monitoringPointNo) {
        this.api.sensor.unbindSensorAndMonitoringPoint([req, this.next]);
      } else {
        this.message.error(this.translate.instant('pleaseFillRequired'));
      }
    }
  }

  imgChange(e) {
    if (e.type === 'success') {
      this.imgLoading = false;
      if (e.file.response.code === 1) {
        this.fileList = [e.file];
        this.req.img = e.file.response.message;
        this.message.success(this.translate.instant('picUploadSuccess'));
      } else {
        this.fileList = [];
        this.message.error(e.file.response.message || this.translate.instant('picUploadFailed'));
      }
    } else if (e.type === 'start') {
      this.imgLoading = true;
    } else if (e.type === 'progress') {
    } else {
      this.message.error(this.translate.instant('picUploadFailed'));
    }
  }

  getPointTypes() {
    this.isLoading = true;
    this.api.monitoringPointType.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.pointTypes = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }
}
