import { Component, OnInit } from '@angular/core';
import { fadeIn } from '../../animation/fade-in';
import { ActivatedRoute } from '@angular/router';
import { ApiService } from '../../shared/service/api.service';
import { NzMessageService } from 'ng-zorro-antd';
import { CheckService } from '../../shared/service/check.service';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-point-paint',
  templateUrl: './point-paint.component.html',
  animations: [fadeIn],
  styles: [`
    .addIcon {
      height: 24px;
    }
    .forDragToPosition {
      position: relative;
    }
  `]
})
export class PointPaintComponent implements OnInit {

  req: any = {};
  isLoading = false;
  isVisible = false;
  isUpdate = false;
  models = [];
  types = [];
  imgUrl = '';
  url = '';
  setData = [];
  unsetData = [];
  alarms = [];
  sensors = [];
  xMax = 0; yMax = 0;
  defaultUrl = '../../../assets/images/Layout.png';
  constructor(private activatedRoute: ActivatedRoute, private api: ApiService,
              private message: NzMessageService, private translate: TranslateService) {}

  ngOnInit() {
    this.activatedRoute.queryParams.subscribe((params) => {
      if (params.img) {
        this.imgUrl = this.api.imgUrl + '/assets/static/monitoringPoint/' + params.img;
        this.url = this.api.imgUrl + '/assets/static/monitoringPoint/' + params.img;
      }
      const img = new Image();
      img.src = this.url;
      img.onload = () => {
        this.xMax = img.width;
        this.yMax = img.height;
      };
      if (params.monitoringPointNo) {
        this.req.monitoringPointNo = params.monitoringPointNo;
        this.getAllPoint(params.monitoringPointNo);
        this.getSensors();
        this.getAlarms();
      }
    });
    document.getElementById('bgImg').onselectstart = document.getElementById('bgImg').ondrag = function() {
      return false;
    };
  }

  getAlarms() {
    this.isLoading = true;
    this.api.alarm.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.alarms = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  init() {
    this.activatedRoute.queryParams.subscribe((params) => {
      if (params.img) {
        this.imgUrl = this.api.imgUrl + '/assets/static/monitoringPoint/' + params.img;
        this.url = this.api.imgUrl + '/assets/static/monitoringPoint/' + params.img;
      }
      if (params.monitoringPointNo) {
        this.req.monitoringPointNo = params.monitoringPointNo;
        this.getAllPoint(params.monitoringPointNo);
        this.getSensors();
        this.getAlarms();
      }
    });
    document.getElementById('bgImg').onselectstart = document.getElementById('bgImg').ondrag = function() {
      return false;
    };
  }

  getAllPoint(monitoringPointNo) {
    this.isLoading = false;
    const req = {monitorPointNo: monitoringPointNo};
    this.api.sensor.getByMonitoringPoint([req, (data) => {
      if (data.constructor === Array) {
        data.map((item, index) => {
          if (item.xaxis && !isNaN(parseInt(item.xaxis, 10))) {
            item.x = parseInt(item.xaxis, 10);
          } else {
            item.x = 0;
          }
          if (item.yaxis && !isNaN(parseInt(item.yaxis, 10))) {
            item.y = parseInt(item.yaxis, 10);
          } else {
            item.y = 0;
          }
          if (index === data.length - 1) {
            this.setData = data;
          }
        });
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
    }]);
  }

  getSensors() {
    this.isLoading = true;
    this.api.sensor.getByFreeAndBindGateway(['', (data) => {
      if (data.constructor === Array) {
        this.sensors = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
    }]);
  }

  add() {
    this.isLoading = true;
    if (!this.req.sensorDeviceNo || !this.req.alarmNo) {
      const message = !this.req.sensorDeviceNo ? 'pleaseChooseSensor' : 'pleaseChooseWarnNo';
      this.message.error(this.translate.instant(message));
      this.isLoading = false;
      return;
    }
    const req = {
      monitoringPointNo: this.req.monitoringPointNo,
      sensorDeviceNos: [this.req.sensorDeviceNo],
      alarmNos: [this.req.alarmNo],
      xaxis: ['1'],
      yaxis: ['1']
    };
    this.api.sensor.bindSensorAndMonitoringPoint([req, (data) => {
      if (data.code === 1) {
        this.req.sensorDeviceNo = '';
        this.req.alarmNo = '';
        this.ngOnInit();
      } else {
        this.message.error(data.message || this.translate.instant('operateFail'));
      }
      this.isLoading = false;
    }]);
  }

  imgOnError() {
    this.url = this.defaultUrl;
    const img = new Image();
    img.src = this.url;
    img.onload = () => {
      this.xMax = img.width;
      this.yMax = img.height;
    };
  }
}
