import { Component, OnInit, ViewChild } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { NzMessageService, NzTreeNode, NzModalService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import { CheckService } from '../../shared/service/check.service';
import { MenuService } from '../../shared/service/menu.service';
import { PermissionService } from '../../shared/service/permission.service';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-role-manage',
  templateUrl: './role-manage.component.html',
  animations: [fadeIn]
})
export class RoleManageComponent implements OnInit {

  req: any = {};
  isLoading = false;
  data = [];
  isVisible = false;
  isUpdate = false;
  @ViewChild('perNodeTree')
  private perNodeTree;
  expandKeys = [];
  checkedKeys = [];
  permissionsArr = [];
  checkedObj = [];
  expandDefault = false;

  constructor(private api: ApiService, private message: NzMessageService,
              private ck: CheckService, private modal: NzModalService,
              private menu: MenuService, public per: PermissionService,
              private translate: TranslateService) {
  }

  ngOnInit() {
    this.init();
  }

  init() {
    this.getData();
    this.getAllPermission();
  }

  getData() {
    this.isLoading = false;
    this.api.role.getAll(['', this.next]);
  }

  getAllPermission() {
    this.isLoading = true;
    this.api.permission.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.initTree(data, 'add');
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
    }]);
  }

  initTree(data, type) {
    const obj: any = [];
    // duishujujinxingqiege
    data.forEach((one, index) => {
      let perRootObj: any = {};
      perRootObj = {
        title: this.menu.transform(one.parentSidebarName),
        key: one.parentSidebarName,
        children: []
      };
      one.sidebarVos.forEach((two, perIndex) => {
        perRootObj.children.push({
          title: this.menu.transform(two.sidebarName),
          key: two.sidebarName,
          children: [],
        });
        two.permissionShowVos.forEach((three, pperIndex) => {
          perRootObj.children[perIndex].children.push({
            title: this.menu.transform(three.permissionName),
            key: three.permissionName,
            isLeaf: true
          });
        });
      });
      obj.push(new NzTreeNode(perRootObj));
      if (index === data.length - 1) {
        this.permissionsArr = obj;
        setTimeout(() => {
          this.checkedKeys = this.checkedObj;
          if (type === 'part') {
            this.isLoading = false;
          }
        }, 100);
      }
    });
  }

  next = (data) => {
    if (data.constructor === Array) {
      this.data = data;
    } else if (data.code === 1) {
      this.message.success(data.message || this.translate.instant('operateSuccess'));
      this.isVisible = false;
      this.init();
    } else if (data.code === 0) {
      this.message.error(data.message || this.translate.instant('operateFail'));
    } else {
      this.message.error(data.message || this.translate.instant('wrongToGetData'));
    }
    this.isLoading = false;
  }

  add() {
    this.isUpdate = false;
    this.checkedKeys = [];
    this.req = {};
    this.isVisible = true;
  }

  edit(one) {
    this.isUpdate = true;
    this.isLoading = true;
    const req = {roleNo: one.roleNo};
    this.req = {...one};
    this.api.permission.getPermissionByRoleNo([req, (data) => {
      if (data.constructor === Array) {
        this.isVisible = true;
        // fenliyiyoudequanxian
        this.checkedObj = [];
        data.forEach((level0) => {
          if (level0.check) {
            this.checkedObj.push(level0.parentSidebarName);
          }
          level0.sidebarVos.forEach((level1) => {
            if (level1.checked) {
              this.checkedObj.push(level1.sidebarName);
            }
            level1.permissionShowVos.forEach((level2) => {
              if (level2.checked) {
                this.checkedObj.push(level2.permissionName);
              }
            });
          });
        });
        // chongxinhuoququanbudequanxian
        this.initTree(data, 'part');
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
    }]);
  }

  save() {
    if (!this.req.permissions || this.req.permissions.length <= 0) {
      this.message.error(this.translate.instant('pleaseChoosePermission'));
    }
    this.isLoading = true;
    const req = {...this.req};
    const ck = {
      field: ['roleName']
    };
    if (!this.ck.formCheck(req, ck)) {
      this.isLoading = false;
      return;
    }
    if (this.isUpdate) {
      this.api.role.updateRole([req, this.next]);
    } else {
      this.api.role.addRole([req, this.next]);
    }
  }

  cancel() {
    this.isVisible = false;
  }

  deleteConfirm(one) {
    this.modal.confirm({
      nzTitle: this.translate.instant('operateTips'),
      nzContent: '<b>' + this.translate.instant('confirmDelete') + '</b>',
      nzOnOk: () => this.delete(one)
    });
  }

  delete(one) {
    this.isLoading = true;
    const req = {
      roleNo: one.roleNo
    };
    this.api.role.deleteRole([req, this.next]);
  }

  // fenliquanxian
  slicePer() {
    const checked = this.perNodeTree.getCheckedNodeList();
    const obj = [];
    if (checked.length > 0) {
      checked.map((one, index) => {
        if (one.level === 2) {
          obj.push(one.key);
        } else {
          one.children.map((two, tIndex) => {
            if (two.level === 2) {
              obj.push(two.key);
            } else {
              two.children.map((three, hIndex) => {
                if (three.level === 2) {
                  obj.push(three.key);
                }
                if (index === checked.length - 1 && tIndex === one.children.length - 1 && hIndex === two.children.length - 1) {
                  this.req.permissions = obj;
                  this.save();
                }
              });
            }
            if (two.level === 2 && index === checked.length - 1 && tIndex === one.children.length - 1) {
              this.req.permissions = obj;
              this.save();
            }
          });
        }
        if (one.level === 2 && index === checked.length - 1) {
          this.req.permissions = obj;
          this.save();
        }
      });
    } else {
      this.message.error(this.translate.instant('pleaseChoosePermission'));
    }
  }
}
