import { Component, OnInit } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { CheckService } from '../../shared/service/check.service';
import { NzMessageService, NzModalService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import { PermissionService } from '../../shared/service/permission.service';
import { NzTreeNode } from 'ng-zorro-antd';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-user-manage',
  templateUrl: './user-manage.component.html',
  animations: [fadeIn],
  styles: [`
    :host::ng-deep .cdk-overlay-pane {
      height: 300px;
      overflow-y: auto;
    }
  `]
})
export class UserManageComponent implements OnInit {

  req: any = {};
  data: any = [];
  isLoading = false;
  isVisible = false;
  isUpdate = false;
  userName = '';
  roles = [];
  factorys = [];
  imgUrl = '';
  fileList = [];
  imgLoading = false;
  nodes = [];
  nodesObj = [];
  selectNode = '';
  expandKeys = [];
  factoryNo = JSON.parse(decodeURIComponent(window.sessionStorage.getItem(encodeURIComponent('_AMap_AMap.IndoorMapFunc')))).factoryNo;
  constructor(private api: ApiService, private message: NzMessageService, private translate: TranslateService,
              private modalService: NzModalService, private ck: CheckService, public per: PermissionService) { }

  ngOnInit() {
    this.imgUrl = this.api.url + '/img/photoUpload?imageType=head';
    this.init();
  }

  init() {
    this.getData();
    this.getFactorys();
  }

  getRoles(req) {
    this.isLoading = true;
    this.api.role.getByFactoryNo([req, (data) => {
      if (data.constructor === Array) {
        this.roles = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getFactorys() {
    this.isLoading = true;
    this.api.factory.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.initFactorys(data);
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  initFactorys(data) {
    const nodes = [];
    const nodesObj = [];
    if (data && data.length > 0) {
      data.map((one, index) => {
        let obj: any = {};
        if (one.resultFactoryAreaVo && one.resultFactoryAreaVo.factoryNo) {
          obj = {
            value: one.resultFactoryAreaVo.factoryNo,
            key: one.resultFactoryAreaVo.factoryNo,
            title: one.resultFactoryAreaVo.factoryName
          };
          if (one.resultFactoryDepartmentVos && one.resultFactoryDepartmentVos.length > 0) {
            obj.children = [];
          }
        }
        if (one.resultFactoryDepartmentVos && one.resultFactoryDepartmentVos.length > 0) {
          one.resultFactoryDepartmentVos.map((two, tIndex) => {
            if (!(one.resultFactoryAreaVo || one.resultFactoryAreaVo.factoryNo) && tIndex === 0 && two.resultFactoryDepartmentVo && two.resultFactoryDepartmentVo.factoryNo) {
              obj = {
                value: two.resultFactoryDepartmentVo.factoryNo,
                key: two.resultFactoryDepartmentVo.factoryNo,
                title: two.resultFactoryDepartmentVo.factoryName
              };
              if (two.resultFactoryLineVos && two.resultFactoryLineVos.length > 0) {
                obj.children = [];
              }
            } else {
              if (two.resultFactoryDepartmentVo && two.resultFactoryDepartmentVo.factoryNo) {
                obj.children.push({
                  value: two.resultFactoryDepartmentVo.factoryNo,
                  key: two.resultFactoryDepartmentVo.factoryNo,
                  title: two.resultFactoryDepartmentVo.factoryName
                });
                if (two.resultFactoryLineVos && two.resultFactoryLineVos.length > 0) {
                  obj.children[tIndex].children = [];
                }
              }
            }
            if (two.resultFactoryLineVos && two.resultFactoryLineVos.length > 0) {
              two.resultFactoryLineVos.map((three, hIndex) => {
                if (!(one.resultFactoryAreaVo || one.resultFactoryAreaVo.factoryNo) && !(two.resultFactoryDepartmentVo || two.resultFactoryDepartmentVo.factoryNo)) {
                  obj.children.push({
                    value: three.factoryNo,
                    key: three.factoryNo,
                    title: three.factoryName
                  });
                } else if (!(one.resultFactoryAreaVo || one.resultFactoryAreaVo.factoryNo) && two.resultFactoryDepartmentVo && two.resultFactoryDepartmentVo.factoryNo) {
                  obj.children.push({
                    value: three.factoryNo,
                    key: three.factoryNo,
                    title: three.factoryName
                  });
                } else {
                  obj.children[tIndex].children.push({
                    value: three.factoryNo,
                    key: three.factoryNo,
                    title: three.factoryName
                  });
                }
                if (hIndex === two.resultFactoryLineVos.length - 1 && tIndex === one.resultFactoryDepartmentVos.length - 1) {
                  nodes.push(new NzTreeNode(obj));
                  nodesObj.push({...obj});
                }
                if (hIndex === two.resultFactoryLineVos.length - 1 && tIndex === one.resultFactoryDepartmentVos.length - 1 && index === data.length - 1) {
                  this.factorys = nodes;
                  this.nodesObj = nodesObj;
                  this.nodes = nodes;
                }
              });
            } else if (tIndex === one.resultFactoryDepartmentVos.length - 1 && index === data.length - 1) {
              nodes.push(new NzTreeNode(obj));
              nodesObj.push({...obj});
              this.factorys = nodes;
              this.nodesObj = nodesObj;
              this.nodes = nodes;
            } else {
              if (tIndex === one.resultFactoryDepartmentVos.length - 1) {
                nodes.push(new NzTreeNode(obj));
                nodesObj.push({...obj});
              }
            }
          });
        } else if (index === data.length - 1) {
          nodes.push(new NzTreeNode(obj));
          nodesObj.push({...obj});
          this.factorys = nodes;
          this.nodesObj = nodesObj;
          this.nodes = nodes;
        } else {
          nodes.push(new NzTreeNode(obj));
          nodesObj.push({...obj});
        }
      });
    }
  }

  onTreeClick(e) {
    this.req.factoryNo = e.node.key;
    this.onChange();
  }

  onClear() {
    this.req.factoryNo = {};
  }

  getData() {
    this.isLoading = true;
    this.api.user.getAll(['', this.next]);
  }

  next = (data) => {
    if (data.constructor === Array) {
      this.data = data;
    } else if (data.code === 1) {
      this.message.success(data.message || this.translate.instant('operateSuccess'));
      this.isVisible = false;
      this.init();
    } else if (data.code === 0) {
      this.message.error(data.message || this.translate.instant('operateFail'));
    } else {
      this.message.error(data.message || this.translate.instant('wrongToGetData'));
    }
    this.isLoading = false;
  }

  add() {
    this.expandKeys = [];
    this.isUpdate = false;
    this.req = {};
    this.nodes = this.factorys;
    this.fileList = [];
    this.selectNode = '';
    this.isVisible = true;
  }

  edit(item) {
    if (item.factoryNo === 'FN27276861545783296') {
      const obj = {
        key: 'FN27276861545783296',
        value: 'FN27276861545783296',
        title: this.translate.instant('boschChina'),
        children: this.nodesObj
      };
      this.nodes = [new NzTreeNode(obj)];
    }
    this.fileList = [{
      name: item.img,
      url: this.api.url + '/assets/static/head/' + item.img,
      status: 'done'
    }];
    const req = {factoryNo: item.factoryNo};
    this.getRoles(req);
    this.req = {...item};
    setTimeout(() => {
      this.selectNode = item.factoryNo;
    }, 300);
    this.isUpdate = true;
    this.isVisible = true;
  }

  cancel() {
    this.isVisible = false;
  }

  save() {
    this.isLoading = true;
    const req = {...this.req};
    const check = {
      field:  this.isUpdate ? ['userName', 'nickName', 'factoryNo'
        , 'phone'] : ['userName', 'password', 'nickName', 'factoryNo', 'phone', 'roleNo'],
      tel: ['phone'],
      email: ['email']
    };
    if (!this.ck.formCheck(req, check)) {
      this.isLoading = false;
      return;
    }
    if (this.isUpdate) {
      this.api.user.updateUser([req, this.next]);
    } else {
      this.api.user.addUser([req, this.next]);
    }
  }

  deleteConfirm(one) {
    this.modalService.confirm({
      nzTitle  : '<i></i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteThisRecord') + '</b>',
      nzOnOk   : () => this.delete(one)
    });
  }

  delete(one) {
    this.isLoading = true;
    const req = {userNo: one.userNo};
    this.api.user.deleteUser([req, this.next]);
  }

  query() {
    this.isLoading = true;
    const req = {userName: this.userName};
    this.api.user.getByUserNameForLike([req, this.next]);
  }

  onSearch() {
    this.query();
  }

  onGetAll() {
    this.getData();
    this.userName = '';
  }

  onChange() {
    const req = {factoryNo: this.req.factoryNo};
    this.getRoles(req);
  }

  imgChange(e) {
    if (e.type === 'success') {
      this.imgLoading = false;
      if (e.file.response.code === 1) {
        this.fileList = [e.file];
        this.req.img = e.file.response.message;
        this.message.success(this.translate.instant('picUploadSuccess'));
      } else {
        this.fileList = [];
        this.message.error(e.file.response.message || this.translate.instant('picUploadFailed'));
      }
    } else if (e.type === 'start') {
      this.imgLoading = true;
    } else if (e.type === 'progress') {
    } else {
      this.message.error(this.translate.instant('picUploadFailed'));
    }
  }
}

