import { Component, OnInit } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { CheckService } from '../../shared/service/check.service';
import { NzMessageService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import { PermissionService } from '../../shared/service/permission.service';
import { ActivatedRoute, Router } from '@angular/router';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-warn-edit',
  templateUrl: './warn-edit.component.html',
  styleUrls: ['./warn-edit.component.scss'],
  animations: [fadeIn]
})
export class WarnEditComponent implements OnInit {

  type = 'add';
  alarmNo = '';
  req: any = {};
  isLoading = false;
  items = [{
    name: 'acc_x',
    key: 'acceleratedX',
    icon: 0,
    per: 'mg',
    min: -16000,
    max: 16000
  }, {
    name: 'acc_y',
    key: 'acceleratedY',
    icon: 0,
    per: 'mg',
    min: -16000,
    max: 16000
  }, {
    name: 'acc_z',
    key: 'acceleratedZ',
    icon: 0,
    per: 'mg',
    min: -16000,
    max: 16000
  }, {
    name: 'mag_r',
    key: 'geomagnetismR',
    icon: 2,
    per: 'Ω',
    min: 0,
    max: 65535
  }, {
    name: 'mag_x',
    key: 'geomagnetismX',
    icon: 2,
    per: 'μT',
    min: -1300,
    max: 1300
  }, {
    name: 'mag_y',
    key: 'geomagnetismY',
    icon: 2,
    per: 'μT',
    min: -1300,
    max: 1300
  }, {
    name: 'mag_z',
    key: 'geomagnetismZ',
    icon: 2,
    per: 'μT',
    min: -2500,
    max: 2500
  }, {
    name: 'gyros_x',
    key: 'gyrosX',
    icon: 1,
    per: '°/s',
    min: -2000,
    max: 2000
  }, {
    name: 'gyros_y',
    key: 'gyrosY',
    icon: 1,
    per: '°/s',
    min: -2000,
    max: 2000
  }, {
    name: 'gyros_z',
    key: 'gyrosZ',
    icon: 1,
    per: '°/s',
    min: -2000,
    max: 2000
  }, {
    name: 'temp',
    key: 'temperature',
    icon: 3,
    per: '℃',
    min: -20,
    max: 60
  }, {
    name: 'humid',
    key: 'humidity',
    icon: 4,
    per: '%rH',
    min: 10,
    max: 90
  }, {
    name: 'press',
    key: 'pressure',
    icon: 5,
    per: 'hPa',
    min: 300,
    max: 1100
  }, {
    name: 'light',
    key: 'light',
    icon: 6,
    per: 'lux',
    min: 0.045,
    max: 188000
  }, {
    name: 'noise',
    key: 'noise',
    icon: 7,
    per: 'mV',
    min: 0.00001,
    max: 2500
  }];

  constructor(private acRouter: ActivatedRoute, private api: ApiService, private ck: CheckService,
              public per: PermissionService, private message: NzMessageService, private router: Router,
              private translate: TranslateService) {
  }

  ngOnInit() {
    this.acRouter.queryParams.subscribe((params) => {
      if (params.alarmNo) {
        this.type = 'edit';
        this.alarmNo = params.alarmNo;
        this.getAlarmInfo();
      }
    });
  }

  getAlarmInfo() {
    this.isLoading = true;
    this.api.alarm.getAll(['', (data) => {
      if (data.constructor === Array) {
        this.req = data.filter((item) => item.alarmNo === this.alarmNo)[0];
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  cancel() {
    this.router.navigate(['/app/alarmWarn/warnInfo']);
  }

  save() {
    const req = {...this.req};
    let flag = 0;
    for (let i = 0; i < this.items.length && flag !== 1; i++) {
      if (!this.req[this.items[i].key + 'Max'] || isNaN(Number(this.req[this.items[i].key + 'Max']))) {
        this.message.error(this.translate.instant(this.items[i].name) + ' ' + this.translate.instant('max') + ' ' + this.translate.instant('fillError'));
        flag = 1;
        return;
      }
      if (!this.req[this.items[i].key + 'Min'] || isNaN(Number(this.req[this.items[i].key + 'Min']))) {
        this.message.error(this.items[i].name + ' ' + this.translate.instant('min') + ' ' + this.translate.instant('fillError'));
        flag = 1;
        return;
      }
      if (Number(this.req[this.items[i].key + 'Max']) > this.items[i].max) {
        this.message.error(this.items[i].name + ' ' + this.translate.instant('max') + ' ' + this.translate.instant('excess') + ' ' + this.translate.instant('maximum') + ' ' + this.items[i].max);
        flag = 1;
        return;
      }
      if (Number(this.req[this.items[i].key + 'Min']) < this.items[i].min) {
        this.message.error(this.items[i].name + ' ' + this.translate.instant('min') + ' ' + this.translate.instant('under') + ' ' + this.translate.instant('minimum') + ' ' + this.items[i].min);
        flag = 1;
        return;
      }
      if (Number(this.req[this.items[i].key + 'Min']) > Number(this.req[this.items[i].key + 'Max'])) {
        this.message.error(this.items[i].name + ' ' + this.translate.instant('min') + ' ' + this.translate.instant('excess') + ' ' + this.items[i].name + ' ' + this.translate.instant('max'));
        flag = 1;
        return;
      }
      const next = (data) => {
        if (data.code === 1) {
          setTimeout(() => {
            this.isLoading = false;
            this.router.navigate(['/app/alarmWarn/warnInfo']);
          }, 2000);
          this.message.success(data.message);
        } else {
          this.message.error(data.message);
          this.isLoading = false;
        }
      };
      if (i === this.items.length - 1) {
        this.isLoading = true;
        if (this.type === 'edit') {
          this.api.alarm.updateAlarm([req, next]);
        } else {
          this.api.alarm.addAlarm([req, next]);
        }
      }
    }
  }
}
