import { Component, OnInit } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { CheckService } from '../../shared/service/check.service';
import { NzMessageService, NzModalService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import { PermissionService } from '../../shared/service/permission.service';
import { Router } from '@angular/router';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-warn-info',
  templateUrl: './warn-info.component.html',
  animations: [fadeIn],
  styleUrls: ['./warn-info.component.scss']
})
export class WarnInfoComponent implements OnInit {

  req: any = {};
  data: any = [];
  isLoading = false;
  isVisible = false;
  isUpdate = false;
  alarmName = '';
  trans = [{
    name: 'acc_x',
    key: 'acceleratedX',
    icon: 'acc',
    per: 'mg',
    min: -16000,
    max: 16000
  }, {
    name: 'acc_y',
    key: 'acceleratedY',
    icon: 'acc',
    per: 'mg',
    min: -16000,
    max: 16000
  }, {
    name: 'acc_z',
    key: 'acceleratedZ',
    icon: 'acc',
    per: 'mg',
    min: -16000,
    max: 16000
  }, {
    name: 'mag_r',
    key: 'geomagnetismR',
    icon: 'mag',
    per: 'Ω',
    min: 0,
    max: 65535
  }, {
    name: 'mag_x',
    key: 'geomagnetismX',
    icon: 'mag',
    per: 'μT',
    min: -1300,
    max: 1300
  }, {
    name: 'mag_y',
    key: 'geomagnetismY',
    icon: 'mag',
    per: 'μT',
    min: -1300,
    max: 1300
  }, {
    name: 'mag_z',
    key: 'geomagnetismZ',
    icon: 'mag',
    per: 'μT',
    min: -2500,
    max: 2500
  }, {
    name: 'gyros_x',
    key: 'gyrosX',
    icon: 'gyros',
    per: '°/s',
    min: -2000,
    max: 2000
  }, {
    name: 'gyros_y',
    key: 'gyrosY',
    icon: 'gyros',
    per: '°/s',
    min: -2000,
    max: 2000
  }, {
    name: 'gyros_z',
    key: 'gyrosZ',
    icon: 'gyros',
    per: '°/s',
    min: -2000,
    max: 2000
  }, {
    name: 'temp',
    key: 'temperature',
    icon: 'temp',
    per: '℃',
    min: -20,
    max: 60
  }, {
    name: 'humid',
    key: 'humidity',
    icon: 'humid',
    per: '%rH',
    min: 10,
    max: 90
  }, {
    name: 'press',
    key: 'pressure',
    icon: 'press',
    per: 'hPa',
    min: 300,
    max: 1100
  }, {
    name: 'light',
    key: 'light',
    icon: 'light',
    per: 'lux',
    min: 0.045,
    max: 188000
  }, {
    name: 'noise',
    key: 'noise',
    icon: 'noise',
    per: 'mV',
    min: 0.00001,
    max: 2500
  }];
  constructor(private api: ApiService, private message: NzMessageService,
              private modalService: NzModalService, private ck: CheckService,
              public per: PermissionService, private router: Router, private translate: TranslateService) { }

  ngOnInit() {
    this.init();
  }

  init() {
    this.getData();
  }

  getData() {
    this.isLoading = true;
    this.api.alarm.getAll(['', this.next]);
  }

  next = (data) => {
    if (data.constructor === Array) {
      this.data = data;
    } else if (data.code === 1) {
      this.message.success(data.message || this.translate.instant('operateSuccess'));
      this.isVisible = false;
      this.init();
    } else if (data.code === 0) {
      this.message.error(data.message || this.translate.instant('operateFail'));
    } else {
      this.message.error(data.message || this.translate.instant('wrongToGetData'));
    }
    this.isLoading = false;
  }

  add() {
    this.router.navigate(['/app/alarmWarn/warnInfo/warnNew']);
  }

  edit(item) {
    this.router.navigate(['/app/alarmWarn/warnInfo/warnEdit'], { queryParams: { alarmNo: item.alarmNo}});
  }

  deleteConfirm(one) {
    this.modalService.confirm({
      nzTitle  : '<i></i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteThisRecord') + '</b>',
      nzOnOk   : () => this.delete(one)
    });
  }

  delete(one) {
    this.isLoading = true;
    const req = {alarmNo: one.alarmNo};
    this.api.alarm.deleteAlarm([req, this.next]);
  }

  query() {
    this.isLoading = true;
    const req = {
      alarmName: this.alarmName
    };
    this.api.alarm.getByAlarmNameForLike([req, this.next]);
  }

  onGetAll() {
    this.alarmName = '';
    this.getData();
  }

  onSearch() {
    this.query();
  }
}
