import { Component, OnInit } from '@angular/core';
import { ApiService } from '../../shared/service/api.service';
import { NzMessageService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-xdk-compare',
  templateUrl: './xdk-compare.component.html',
  animations: [fadeIn],
  styles: []
})
export class XdkCompareComponent implements OnInit {

  deviceNos = [];
  isLoading = false;
  req: any = {};
  params: any = [{value: 'temp'}, {value: 'press'}, {value: 'humid'},
    {value: 'mag_x'}, {value: 'mag_y'}, {value: 'mag_z'},
    {value: 'mag_r'}, {value: 'gyros_x'}, {value: 'gyros_y'},
    {value: 'gyros_z'}, {value: 'gyros'}, {value: 'light'},
    {value: 'noise'}];
  optionArray = [];
  option = {
    title: {
      text: ''
    },
    tooltip: {
      trigger: 'axis'
    },
    legend: {
      data: []
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      containLabel: true
    },
    xAxis: {
      type: 'category',
      boundaryGap: false,
      data: []
    },
    yAxis: {
      type: 'value'
    },
    series: []
  };
  constructor(private api: ApiService, private message: NzMessageService, private translate: TranslateService) { }

  ngOnInit() {
    this.init();
  }

  init() {
    this.getDeviceNos();
  }

  getDeviceNos() {
    this.isLoading = true;
    const req = {type: 'XDK'};
    this.api.sensor.getUnFreeByType([req, (data) => {
      if (data.constructor === Array) {
        this.deviceNos = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  onSearch() {
    if (!this.req.startTime || !this.req.stopTime || this.req.deviceNo.length <= 0 || !this.req.parameter || this.req.parameter.length <= 0) {
      const msg = !this.req.startTime ? this.translate.instant('pleaseChooseStartTime') : !this.req.stopTime ? this.translate.instant('pleaseChooseEndTime') : this.req.deviceNo.length <= 0 ? 'pleaseChooseSensor' : 'pleaseChooseCompareParams';
      this.message.error(this.translate.instant(msg));
    } else {
      const req: any = {
        startTime: this.req.startTime,
        stopTime: this.req.stopTime,
        deviceNo: this.req.deviceNo,
        offset: (- new Date().getTimezoneOffset() / 60).toString()
      };
      this.optionArray = [];
      this.req.parameter.map((item, index) => {
        this.isLoading = true;
        req.parameter = item;
        this.api.dataComparison.getDataComparisonForXDK([req, (data) => {
          if (data.length > 0) {
            this.initChart(item, data, index);
          } else {
            this.message.error(data.message || this.translate.instant('noData'));
          }
          this.isLoading = false;
        }]);
      });
    }
  }

  initChart(type, data, num) {
    const word = this.translate.instant('type');
    if (data.length > 0) {
      const option = {...this.option};
      option.title.text = word + this.translate.instant('data');
      data.map((item, index) => {
        option.legend.data.push(this.translate.instant('sensor') + item.resultSensorVo.sensorName + word + this.translate.instant('data'));
        if (item.resultDataComparisonVos.length <= 0) {
          option.series[index] = {
            name: this.translate.instant('sensor') + item.resultSensorVo.sensorName + word + this.translate.instant('data'),
            type: 'line',
            data: ['-']
          };
        } else {
          const obj = [];
          const time = [];
          item.resultDataComparisonVos.map((one, ind) => {
            time.push(this.transTime(Number(one.time)));
            obj.push(Number(one.value));
            if (ind === item.resultDataComparisonVos.length - 1) {
              option.series[index] = {
                name: this.translate.instant('sensor') + item.resultSensorVo.sensorName + word + this.translate.instant('data'),
                type: 'line',
                data: obj
              };
              option.legend.data.push(this.translate.instant('sensor') + item.resultSensorVo.sensorName + word + this.translate.instant('data'));
              option.xAxis.data = time;
            }
          });
        }
        if (index === data.length - 1) {
          option.xAxis.data = option.xAxis.data || ['-'];
          this.optionArray[num] = option;
        }
      });
    }
  }


  private transTime(value) {
    const date: any = new Date(value - 0);
    const texts = [date.getFullYear(), this.addZero(date.getMonth() + 1), this.addZero(date.getDate())];
    const time = [this.addZero(date.getHours()), this.addZero(date.getMinutes()), this.addZero(date.getSeconds())];
    return texts.join('-') + '\n' + time.join(':');
  }

  private addZero(date) {
    if (date.toString().length === 1) {
      date = '0' + date.toString();
    }
    return date;
  }
}
