import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { ApiService } from '../../shared/service/api.service';
import { NzMessageService } from 'ng-zorro-antd';
import { fadeIn } from '../../animation/fade-in';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-xdk-detail',
  templateUrl: './xdk-detail.component.html',
  animations: [fadeIn],
  styles: [`
    .chartPie,.chartPie2 {
      width: 500px;
      display: inline-block;
      margin-bottom: 30px;
    }
    :host ::ng-deep .chartPie div canvas {
      background: url(../../../assets/images/chartbg.png) no-repeat;
      background-position-x: center;
      background-size: 55%;
    }
    :host ::ng-deep .chartPie2 div canvas {
      background: url(../../../assets/images/chartbg2.png) no-repeat;
      background-position-x: center;
      background-size: 55%;
    }
    .chartBox {
      width: 1500px;
    }
    .oneItem {
      width: 130px;
      height: 130px;
      display: inline-block;
      position: relative;
      text-align: center;
    }

    .up .oneItem {
      margin: 10px 10px 50px 10px;
    }

    .down .oneItem {
      margin: 55px 10px 10px 10px;
    }

    .oneItem .text{
      position: absolute;
      top: 70px;
      left: 34px;
      width: 60px;
    }

    .title1 {
      display: inline-block;
      width: 500px;
      text-align: center;
      font-size: 20px;
      margin-bottom: 40px;
      margin-top: -10px;
    }

    .up .oneItem .topIcon{
      position: absolute;
      left: -15px;
      top: -30px;
      height: 30px;
      text-align: center;
      width: 130px;
      background: url('../../../assets/images/down.png') no-repeat;
      background-size: 80% 150%;
      transform: rotate(180deg);
      -ms-transform: rotate(180deg);
      -moz-transform: rotate(180deg);
      -webkit-transform: rotate(180deg);
      -o-transform: rotate(180deg);
    }

    .down .oneItem .topIcon{
      position: absolute;
      left: 9px;
      top: 130px;
      height: 30px;
      text-align: center;
      width: 130px;
      background: url('../../../assets/images/down.png') no-repeat;
      background-size: 80% 150%;
    }

    .up .oneItem .textBottom{
      position: absolute;
      top: 130px;
      width: 130px;
    }

    .down .oneItem .textBottom{
      position: absolute;
      bottom: 130px;
      width: 130px;
    }
    .up {
      margin-bottom: 10px;
      border-bottom: 1px solid #ccc;
      padding-bottom: 10px;
    }
  `]
})
export class XdkDetailComponent implements OnInit {
  option1 = {
    tooltip : {
      formatter: '{b} : {c}%'
    },
    series: [
      {
        name: '',
        type: 'gauge',
        startAngle: 240,
        endAngle: -60,
        itemStyle: {
          color: '#444'
        },
        point: {
          show: true,
          width: 2
        },
        axisLine: {
          show: true,
          lineStyle: {
            opacity: 0
          }
        },
        axisLabel: {
          distance: -45
        },
        splitLine: {show: false},
        axisTick: {show: false},
        detail: {show: false},
        data: []
      }
    ]
  };
  option2 = {
    tooltip : {
      formatter: '{b} : {c}%'
    },
    series: [
      {
        name: '',
        type: 'gauge',
        startAngle: 203,
        min: 0,
        max: 100,
        endAngle: -23,
        itemStyle: {
          color: '#444'
        },
        point: {
          show: 0
        },
        axisLine: {
          show: true,
          lineStyle: {
            opacity: 0
          }
        },
        axisLabel: {
          distance: -45
        },
        splitLine: {show: false},
        axisTick: {show: false},
        detail: {show: false},
        data: []
      }
    ]
  };
  option3 = {
    tooltip : {
      formatter: '{b} : {c}%'
    },
    series: [
      {
        name: '',
        type: 'gauge',
        startAngle: 198,
        endAngle: -18,
        itemStyle: {
          color: '#444'
        },
        point: {
          show: 0
        },
        axisLine: {
          show: true,
          lineStyle: {
            opacity: 0
          }
        },
        axisLabel: {
          distance: -45
        },
        splitLine: {show: false},
        axisTick: {show: false},
        detail: {show: false},
        data: []
      }
    ]
  };
  selectDeviceNo = '';
  isLoading = false;
  data = {xdkRealDataVo: {sensorName: '', SN: ''}, alarmVo: {}};
  occurs = ['', '', ''];
  itemsObj = [{
    key: 'temperature',
    label: 'temp',
    per: '℃',
    index: 1
  }, {
    key: 'pressure',
    label: 'press',
    per: 'kPa',
    index: 2
  }, {
    key: 'humidity',
    label: 'humid',
    per: '%rH',
    index: 3
  }, {
    key: 'geomagnetismX',
    label: 'mag_x',
    per: 'μT',
    index: 4
  }, {
    key: 'geomagnetismY',
    label: 'mag_y',
    per: 'μT',
    index: 5
  }, {
    key: 'geomagnetismZ',
    label: 'mag_z',
    per: 'μT',
    index: 6
  }, {
    key: 'geomagnetismR',
    label: 'mag_r',
    per: 'μT',
    index: 7
  }, {
    key: 'gyrosX',
    label: 'gyros_x',
    per: '°/s',
    index: 8
  }, {
    key: 'gyrosY',
    label: 'gyros_y',
    per: '°/s',
    index: 9
  }, {
    key: 'gyrosZ',
    label: 'gyros_z',
    per: '°/s',
    index: 10
  }, {
    key: 'acceleratedX',
    label: 'acc_x',
    per: 'mg',
    index: 12
  }, {
    key: 'acceleratedY',
    label: 'acc_y',
    per: 'mg',
    index: 13
  }, {
    key: 'acceleratedZ',
    label: 'acc_y',
    per: 'mg',
    index: 14
  }, {
    key: 'light',
    label: 'light',
    per: 'lux',
    index: 15
  }, {
    key: 'noise',
    label: 'noise',
    per: 'mV',
    index: 16
  }];
  constructor(private api: ApiService, private acRouter: ActivatedRoute,
              private message: NzMessageService, private translate: TranslateService) { }

  ngOnInit() {
    this.acRouter.queryParams.subscribe((params) => {
      this.selectDeviceNo = params.deviceNo;
      if (params.deviceNo) {
        this.getData();
      }
    });
  }

  getData() {
    this.isLoading = true;
    const req = {deviceNo: this.selectDeviceNo};
    this.api.data.getXDK([req, (data) => {
      if (data && data.xdkRealDataVo) {
        this.data = data;
        const option1: any = {...this.option1};
        option1.series[0].data = [parseFloat(data.xdkRealDataVo.temp)];
        option1.tooltip.formatter = '{c}℃';
        option1.series[0].name = this.translate.instant('temp');
        option1.series[0].min = -20;
        option1.series[0].max = 60;
        this.occurs[0] = data && data.xdkRealDataVo && data.xdkRealDataVo.temp ? data.xdkRealDataVo.temp + '℃' : '-' + '℃';
        this.option1 = option1;
        const option2 = {...this.option2};
        option2.series[0].data = [parseFloat('300')];
        option2.tooltip.formatter = '{c}kPa';
        option2.series[0].name = this.translate.instant('press');
        option2.series[0].min = 300;
        option2.series[0].max = 1100;
        this.occurs[1] = data && data.xdkRealDataVo && data.xdkRealDataVo.press ? data.xdkRealDataVo.press + 'kPa' : '-' + 'kPa';
        this.option2 = option2;
        const option3: any = {...this.option3};
        option3.series[0].data = [parseFloat(data.xdkRealDataVo.humid)];
        option3.tooltip.formatter = '{c}%rH';
        option3.series[0].name = this.translate.instant('humid');
        option3.series[0].min = 10;
        option3.series[0].max = 90;
        this.occurs[2] = data && data.xdkRealDataVo && data.xdkRealDataVo.humid ? data.xdkRealDataVo.humid + '%rH' : '-' + '%rH';
        this.option3 = option3;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

}
