import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { NzMessageService } from 'ng-zorro-antd';
import { ApiService } from '../../shared/service/api.service';
import { fadeIn } from '../../animation/fade-in';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-xdk-history',
  templateUrl: './xdk-history.component.html',
  animations: [fadeIn],
  styles: []
})
export class XdkHistoryComponent implements OnInit {

  params: any = [{value: 'temp'}, {value: 'press'}, {value: 'humid'},
    {value: 'mag_x'}, {value: 'mag_y'}, {value: 'mag_z'},
    {value: 'mag_r'}, {value: 'gyros_x'}, {value: 'gyros_y'},
    {value: 'gyros_z'}, {value: 'gyros'}, {value: 'light'},
    {value: 'noise'}];
  req: any = {};
  optionArray = [];
  option = {
    title: {
      text: ''
    },
    tooltip: {
      trigger: 'axis'
    },
    legend: {
      data: []
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      containLabel: true
    },
    xAxis: {
      type: 'category',
      boundaryGap: false,
      data: []
    },
    yAxis: {
      type: 'value'
    },
    series: [
      {
        name: '',
        type: 'line',
        data: []
      }
    ]
  };
  isLoading = false;
  selectDevice: any = {};
  devices = [];
  constructor(private api: ApiService, private acRouter: ActivatedRoute,
              private message: NzMessageService, private translate: TranslateService) { }

  ngOnInit() {
    this.getDevices();
    this.acRouter.queryParams.subscribe((params) => {
      this.selectDevice = params;
      if (this.selectDevice.deviceNo) {
        this.req.deviceNo = this.selectDevice.deviceNo;
      }
    });
  }

  init() {
    this.getDevices();
  }

  getDevices() {
    this.isLoading = true;
    const req = {type: 'XDK'};
    this.api.sensor.getUnFreeByType([req, (data) => {
      if (data.constructor === Array) {
        this.devices = data;
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  getData(req, type) {
    this.isLoading = true;
    this.api.data.getXDKHistoryData([req, (data) => {
      if (data.constructor === Array) {
        this.initChart(data, type);
      } else {
        this.message.error(data.message || this.translate.instant('wrongToGetData'));
      }
      this.isLoading = false;
    }]);
  }

  initChart(data, type) {
    const option = {...this.option};
    option.title.text = this.translate.instant(type) + this.translate.instant('data');
    option.legend.data = this.translate.instant(type);
    const time = [];
    const obj = [];
    const len = data.length - 1;
    data.map((item, index) => {
      time.push(this.transTime(item.time));
      obj.push(item.value);
      if (len === index) {
        option.xAxis.data = time;
        option.series[0].data = obj;
        this.optionArray.push({...option});
      }
    });
  }

  output() {}

  onSearch() {
    if (!this.req.deviceNo) {
      this.message.error(this.translate.instant('pleaseChooseSensor'));
    }
    if (!this.req.startTime || !this.req.endTime || !this.req.params || this.req.params.length <= 0) {
      this.message.error(!this.req.startTime ? this.translate.instant('pleaseChooseStartTime') : !this.req.endTime ? this.translate.instant('pleaseChooseEndTime') : this.translate.instant('pleaseChooseParams'));
    } else {
      const req: any = {
        deviceNo: this.req.deviceNo,
        startTime: this.req.startTime,
        endTime: this.req.endTime,
        offset: (- new Date().getTimezoneOffset() / 60).toString()
      };
      this.optionArray = [];
      this.req.params.map((item) => {
        req.parameter = item;
        this.getData({...req}, item);
      });
    }
  }

  private transTime(value) {
    const date: any = new Date(value - 0);
    const texts = [date.getFullYear(), this.addZero(date.getMonth() + 1), this.addZero(date.getDate())];
    const time = [this.addZero(date.getHours()), this.addZero(date.getMinutes()), this.addZero(date.getSeconds())];
    return texts.join('-') + '\n' + time.join(':');
  }

  private addZero(date) {
    if (date.toString().length === 1) {
      date = '0' + date.toString();
    }
    return date;
  }
}
